# mode: run
# tag: cpp

from libcpp.vector cimport vector

def memview_test(L, int i, int x):
    """
    >>> memview_test(range(10), 7, 100)
    [0, 1, 2, 3, 4, 5, 6, 100, 8, 9]
    """
    cdef vector[int] v = L
    cdef int[::1] mv = <int[:len(L)]> &v[0]
    mv[i] = x
    return v



from __future__ import print_function

DEF FavouriteFood = u"spam"
DEF ArraySize = 42
DEF OtherArraySize = 2 * ArraySize + 17

cdef int a1[ArraySize]
cdef int a2[OtherArraySize]
print("I like", FavouriteFood)


# distutils: language = c++

from libcpp.string cimport string

def get_bytes():
    py_bytes_object = b'hello world'
    cdef string s = py_bytes_object

    s.append('abc')
    py_bytes_object = s
    return py_bytes_object




# ticket: 400

cimport cython


@cython.test_fail_if_path_exists("//SingleAssignmentNode//TypecastNode")
@cython.test_assert_path_exists(
    "//PythonCapiCallNode",
    "//PythonCapiCallNode/PythonCapiFunctionNode/@cname = '__Pyx_truncl'",
)
def long_double_to_float_int(long double x):
    """
    >>> long_double_to_float_int(4.1)
    4.0
    >>> long_double_to_float_int(-4.1)
    -4.0
    >>> long_double_to_float_int(4)
    4.0
    """
    cdef float r = int(x)
    return r



# cython: binding=True, language_level=3
# mode: run
# tag: cyfunction

import inspect

try:
    sig = inspect.Signature.from_callable
except AttributeError:
    sig = inspect.Signature.from_function


def signatures_match(f1, f2):
    if sig(f1) == sig(f2):
        return None  # nothing to show in doctest
    return sig(f1), sig(f2)


def b(a, b, c):
    """
    >>> def py_b(a, b, c): pass
    >>> signatures_match(b, py_b)
    """


def c(a, b, c=1):
    """
    >>> def py_c(a, b, c=1): pass
    >>> signatures_match(c, py_c)
    """


def d(a, b, *, c = 88):
    """
    >>> def py_d(a, b, *, c = 88): pass
    >>> signatures_match(d, py_d)
    """


def e(a, b, c = 88, **kwds):
    """
    >>> def py_e(a, b, c = 88, **kwds): pass
    >>> signatures_match(e, py_e)
    """


def f(a, b, *, c, d = 42):
    """
    >>> def py_f(a, b, *, c, d = 42): pass
    >>> signatures_match(f, py_f)
    """


def g(a, b, *, c, d = 42, e = 17, f, **kwds):
    """
    >>> def py_g(a, b, *, c, d = 42, e = 17, f, **kwds): pass
    >>> signatures_match(g, py_g)
    """


def h(a, b, *args, c, d = 42, e = 17, f, **kwds):
    """
    >>> def py_h(a, b, *args, c, d = 42, e = 17, f, **kwds): pass
    >>> signatures_match(h, py_h)
    """


def k(a, b, c=1, *args, d = 42, e = 17, f, **kwds):
    """
    >>> def py_k(a, b, c=1, *args, d = 42, e = 17, f, **kwds): pass
    >>> signatures_match(k, py_k)
    """


def l(*, a, b, c = 88):
    """
    >>> def py_l(*, a, b, c = 88): pass
    >>> signatures_match(l, py_l)
    """


def m(a, *, b, c = 88):
    """
    >>> def py_m(a, *, b, c = 88): pass
    >>> signatures_match(m, py_m)
    """
    a, b, c = b, c, a


def n(a, *, b, c = 88):
    """
    >>> def py_n(a, *, b, c = 88): pass
    >>> signatures_match(n, py_n)
    """


cpdef cp1(a, b):
    """
    >>> def py_cp1(a, b): pass
    >>> signatures_match(cp1, py_cp1)
    """


# Currently broken, see GH #1864
cpdef cp2(a, b=True):
    """
    >>> def py_cp2(a, b=True): pass

    #>>> signatures_match(cp2, py_cp2)
    """


# Currently broken, see GH #1864
cpdef cp3(a=1, b=True):
    """
    >>> def py_cp3(a=1, b=True): pass

    #>>> signatures_match(cp3, py_cp3)
    """



# mode: compile

cdef class Spam:
    cdef public char c
    cdef public int i
    cdef public long l
    cdef public unsigned char uc
    cdef public unsigned int ui
    cdef public unsigned long ul
    cdef public float f
    cdef public double d
    cdef public char *s
    cdef readonly char[42] a
    cdef public object o
    cdef readonly int r
    cdef readonly Spam e



# mode: error
# tag: cpp

from libcpp.vector cimport vector

def vector_is_none(vector[int] iv):
    # TODO: this isn't strictly wrong, so it might be allowed as a 'feature' at some point
    if iv is None:
        pass


_ERRORS = """
8:10: Invalid types for 'is' (vector[int], Python object)
"""



"""
Non-test that prints debug information about the current build environment.
"""

from __future__ import print_function

import os
import sys
from distutils import sysconfig


cdef extern from *:
    """
    #ifndef PyLong_SHIFT
    #define PyLong_SHIFT 0
    typedef int digit;
    typedef int sdigit;
    #endif
    #ifndef PyLong_BASE
    #define PyLong_BASE 0
    #endif
    #ifndef PyLong_MASK
    #define PyLong_MASK 0
    #endif
    #ifndef SIZEOF_UINTPTR_T
    #define SIZEOF_UINTPTR_T 0
    #endif
    #ifndef SIZEOF_OFF_T
    #define SIZEOF_OFF_T 0
    #endif
    """
    # Python runtime
    cdef long PY_VERSION_HEX

    # Cython config
    cdef int CYTHON_COMPILING_IN_CPYTHON
    cdef int CYTHON_COMPILING_IN_PYPY
    cdef int CYTHON_COMPILING_IN_PYSTON
    cdef int CYTHON_COMPILING_IN_NOGIL
    cdef int CYTHON_USE_PYLONG_INTERNALS
    cdef int CYTHON_USE_PYLIST_INTERNALS
    cdef int CYTHON_USE_UNICODE_INTERNALS
    cdef int CYTHON_USE_UNICODE_WRITER
    cdef int CYTHON_AVOID_BORROWED_REFS
    cdef int CYTHON_ASSUME_SAFE_MACROS
    cdef int CYTHON_UNPACK_METHODS
    cdef int CYTHON_FAST_THREAD_STATE
    cdef int CYTHON_FAST_PYCALL
    cdef int CYTHON_PEP489_MULTI_PHASE_INIT
    cdef int CYTHON_USE_TP_FINALIZE

    # C and platform specifics
    cdef int SIZEOF_INT
    cdef int SIZEOF_LONG
    cdef int SIZEOF_SIZE_T
    cdef int SIZEOF_LONG_LONG
    cdef int SIZEOF_VOID_P
    cdef int SIZEOF_OFF_T
    cdef int SIZEOF_UINTPTR_T

    # PyLong internals
    cdef long PyLong_BASE
    cdef long PyLong_MASK
    cdef int PyLong_SHIFT
    cdef int digit
    cdef int sdigit


def config_var(name, default=''):
    return sysconfig.get_config_var(name) or default

get_env = os.environ.get


print(f"""Python build environment:
Python  {sys.version_info}
PY_VERSION_HEX  0x{PY_VERSION_HEX:X}

CYTHON_COMPILING_IN_CPYTHON  {CYTHON_COMPILING_IN_CPYTHON}
CYTHON_COMPILING_IN_PYPY  {CYTHON_COMPILING_IN_PYPY}
CYTHON_COMPILING_IN_PYSTON  {CYTHON_COMPILING_IN_PYSTON}
CYTHON_COMPILING_IN_NOGIL  {CYTHON_COMPILING_IN_NOGIL}

CYTHON_USE_PYLONG_INTERNALS  {CYTHON_USE_PYLONG_INTERNALS}
CYTHON_USE_PYLIST_INTERNALS  {CYTHON_USE_PYLIST_INTERNALS}
CYTHON_USE_UNICODE_INTERNALS  {CYTHON_USE_UNICODE_INTERNALS}
CYTHON_USE_UNICODE_WRITER  {CYTHON_USE_UNICODE_WRITER}
CYTHON_AVOID_BORROWED_REFS  {CYTHON_AVOID_BORROWED_REFS}
CYTHON_ASSUME_SAFE_MACROS  {CYTHON_ASSUME_SAFE_MACROS}
CYTHON_UNPACK_METHODS  {CYTHON_UNPACK_METHODS}
CYTHON_FAST_THREAD_STATE  {CYTHON_FAST_THREAD_STATE}
CYTHON_FAST_PYCALL  {CYTHON_FAST_PYCALL}
CYTHON_PEP489_MULTI_PHASE_INIT  {CYTHON_PEP489_MULTI_PHASE_INIT}
CYTHON_USE_TP_FINALIZE  {CYTHON_USE_TP_FINALIZE}

PyLong_BASE  0x{PyLong_BASE:X}
PyLong_MASK  0x{PyLong_MASK:X}
PyLong_SHIFT  {PyLong_SHIFT}
sizeof(digit)   {sizeof(digit)}
sizeof(sdigit)  {sizeof(sdigit)}
sys.int_info  {getattr(sys, 'int_info', '-')}
sys.getsizeof(1, 2**14, 2**15, 2**29, 2**30, 2**59, 2**60, 2**64)  {tuple(sys.getsizeof(n) for n in (1, 2**14, 2**15, 2**29, 2**30, 2**59, 2**60, 2**64))}

SIZEOF_INT  {SIZEOF_INT}  ({sizeof(int)})
SIZEOF_LONG  {SIZEOF_LONG}  ({sizeof(long)})
SIZEOF_SIZE_T  {SIZEOF_SIZE_T}  ({sizeof(Py_ssize_t)}, {getattr(sys, 'maxsize', getattr(sys, 'maxint', None))})
SIZEOF_LONG_LONG  {SIZEOF_LONG_LONG}  ({sizeof(long long)})
SIZEOF_VOID_P  {SIZEOF_VOID_P}  ({sizeof(void*)})
SIZEOF_UINTPTR_T  {SIZEOF_UINTPTR_T}  ({sizeof(unsigned int *)})
SIZEOF_OFF_T  {SIZEOF_OFF_T}

Distutils:
INCDIR = {sysconfig.get_python_inc()}
LIBS = {config_var('LIBS')}
LIBDIR = {config_var('LIBDIR')}
LIBPL = {config_var('LIBPL')}
Python LIBRARY = {config_var('LIBRARY')}
LINKFORSHARED = {config_var('LINKFORSHARED')}

CC (distutils) = {config_var('CC')}
CC (env) = {get_env('CC', '')}
CFLAGS (distutils) = {config_var('CFLAGS')}
CFLAGS (env) = {get_env('CFLAGS', '')}
LINKCC (distutils) = {config_var('LINKCC')}
LINKCC (env) = {get_env('LINKCC', '')}

Encodings:
sys maxunicode = {sys.maxunicode}
LANG (env) = {get_env('LANG', '')}
PYTHONIOENCODING (env) = {get_env('PYTHONIOENCODING', '')}
sys stdout encoding = {sys.stdout.encoding}
sys default encoding = {sys.getdefaultencoding()}
sys FS encoding = {sys.getfilesystemencoding()}
""")



# mode: compile

cdef extern from "Python.h":
    ctypedef struct PyTypeObject:
        pass

    ctypedef struct PyObject:
        Py_ssize_t ob_refcnt
        PyTypeObject *ob_type

cdef extern from "Python.h":
    """
    #if PY_MAJOR_VERSION < 3
     #include "longintrepr.h"
    #endif
    """
    cdef struct _longobject:
        int ob_refcnt
        PyTypeObject *ob_type
#        int ob_size            # not in Py3k
        unsigned int *ob_digit

def test(temp = long(0)):
    cdef _longobject *l
    l = <_longobject *> temp
    #print sizeof(l.ob_size)    # not in Py3k
    print sizeof(l.ob_digit[0])



import cython

#@cython.test_fail_if_path_exists('//MergedDictNode')
def wrap_passthrough(f):
    """
    >>> def f(a=1): return a
    >>> wrapped = wrap_passthrough(f)
    >>> wrapped(1)
    CALLED
    1
    >>> wrapped(a=2)
    CALLED
    2
    """
    def wrapper(*args, **kwargs):
        print("CALLED")
        return f(*args, **kwargs)
    return wrapper


@cython.test_fail_if_path_exists('//MergedDictNode')
def unused(*args, **kwargs):
    """
    >>> unused()
    ()
    >>> unused(1, 2)
    (1, 2)
    """
    return args


@cython.test_fail_if_path_exists('//MergedDictNode')
def used_in_closure(**kwargs):
    """
    >>> used_in_closure()
    >>> d = {}
    >>> used_in_closure(**d)
    >>> d  # must not be modified
    {}
    """
    def func():
        kwargs['test'] = 1
    return func()


@cython.test_fail_if_path_exists('//MergedDictNode')
def modify_in_closure(**kwargs):
    """
    >>> func = modify_in_closure()
    >>> func()

    >>> d = {}
    >>> func = modify_in_closure(**d)
    >>> func()
    >>> d  # must not be modified
    {}
    """
    def func():
        kwargs['test'] = 1
    return func


@cython.test_assert_path_exists('//MergedDictNode')
def wrap_passthrough_more(f):
    """
    >>> def f(a=1, test=2):
    ...     return a, test
    >>> wrapped = wrap_passthrough_more(f)
    >>> wrapped(1)
    CALLED
    (1, 1)
    >>> wrapped(a=2)
    CALLED
    (2, 1)
    """
    def wrapper(*args, **kwargs):
        print("CALLED")
        return f(*args, test=1, **kwargs)
    return wrapper


#@cython.test_fail_if_path_exists('//MergedDictNode')
def wrap_passthrough2(f):
    """
    >>> def f(a=1): return a
    >>> wrapped = wrap_passthrough2(f)
    >>> wrapped(1)
    CALLED
    1
    >>> wrapped(a=2)
    CALLED
    2
    """
    def wrapper(*args, **kwargs):
        print("CALLED")
        f(*args, **kwargs)
        return f(*args, **kwargs)
    return wrapper


#@cython.test_fail_if_path_exists('//MergedDictNode')
def wrap_modify(f):
    """
    >>> def f(a=1, test=2):
    ...     return a, test

    >>> wrapped = wrap_modify(f)
    >>> wrapped(1)
    CALLED
    (1, 1)
    >>> wrapped(a=2)
    CALLED
    (2, 1)
    >>> wrapped(a=2, test=3)
    CALLED
    (2, 1)
    """
    def wrapper(*args, **kwargs):
        print("CALLED")
        kwargs['test'] = 1
        return f(*args, **kwargs)
    return wrapper


#@cython.test_fail_if_path_exists('//MergedDictNode')
def wrap_modify_mix(f):
    """
    >>> def f(a=1, test=2):
    ...     return a, test

    >>> wrapped = wrap_modify_mix(f)
    >>> wrapped(1)
    CALLED
    (1, 1)
    >>> wrapped(a=2)
    CALLED
    (2, 1)
    >>> wrapped(a=2, test=3)
    CALLED
    (2, 1)
    """
    def wrapper(*args, **kwargs):
        print("CALLED")
        f(*args, **kwargs)
        kwargs['test'] = 1
        return f(*args, **kwargs)
    return wrapper


@cython.test_assert_path_exists('//MergedDictNode')
def wrap_modify_func(f):
    """
    >>> def f(a=1, test=2):
    ...     return a, test

    >>> wrapped = wrap_modify_func(f)
    >>> wrapped(1)
    CALLED
    (1, 1)
    >>> wrapped(a=2)
    CALLED
    (2, 1)
    >>> wrapped(a=2, test=3)
    CALLED
    (2, 1)
    """
    def modify(kw):
        kw['test'] = 1
        return kw

    def wrapper(*args, **kwargs):
        print("CALLED")
        return f(*args, **modify(kwargs))
    return wrapper


def modify_in_function():
    """
    >>> modify_in_function()
    {'foo': 'bar'}
    {'foo': 'bar'}
    """
    def inner(**kwds):
        kwds['foo'] = 'modified'
    d = {'foo': 'bar'}
    print(d)
    inner(**d)
    print(d)


#@cython.test_assert_path_exists('//MergedDictNode')
def wrap_modify_func_mix(f):
    """
    >>> def f(a=1, test=2):
    ...     return a, test

    >>> wrapped = wrap_modify_func_mix(f)
    >>> wrapped(1)
    CALLED
    (1, 1)
    >>> wrapped(a=2)
    CALLED
    (2, 1)
    >>> wrapped(a=2, test=3)
    CALLED
    (2, 1)
    """
    def modify(kw):
        kw['test'] = 1
        return kw

    def wrapper(*args, **kwargs):
        print("CALLED")
        f(*args, **kwargs)
        return f(*args, **modify(kwargs))
    return wrapper


#@cython.test_fail_if_path_exists('//MergedDictNode')
def wrap_reassign(f):
    """
    >>> def f(a=1, test=2):
    ...     return a, test
    >>> wrapped = wrap_reassign(f)
    >>> wrapped(1)
    CALLED
    (1, 1)
    >>> wrapped(a=2)
    CALLED
    (1, 1)
    >>> wrapped(a=2, test=3)
    CALLED
    (1, 1)
    """
    def wrapper(*args, **kwargs):
        print("CALLED")
        kwargs = {'test': 1}
        return f(*args, **kwargs)
    return wrapper


#@cython.test_fail_if_path_exists('//MergedDictNode')
def kwargs_metaclass(**kwargs):
    """
    >>> K = kwargs_metaclass()
    >>> K = kwargs_metaclass(metaclass=type)
    """
    class K(**kwargs):
        pass
    return K



import sys

def reraise(f, exc):
    """
    >>> def f(exc): raise exc
    >>> reraise(f, TypeError)
    Traceback (most recent call last):
    TypeError

    >>> def f(exc): raise exc('hiho')
    >>> reraise(f, TypeError)
    Traceback (most recent call last):
    TypeError: hiho
    """
    try:
        f(exc)
    except:
        assert sys.exc_info()[0] is exc, str(sys.exc_info()[1])
        raise

def reraise_original(f, exc, raise_catch):
    """
    >>> def f(exc): raise exc
    >>> def raise_catch_py():
    ...     try: raise ValueError
    ...     except: pass

    >>> reraise_original(f, TypeError, raise_catch_py)
    Traceback (most recent call last):
    TypeError

    >>> reraise_original(f, TypeError, raise_catch_cy)
    Traceback (most recent call last):
    TypeError

    >>> reraise_original(f, TypeError, raise_catch_cy_non_empty)
    Traceback (most recent call last):
    TypeError
    """
    try:
        f(exc)
    except:
        raise_catch()
        assert sys.exc_info()[0] is exc, str(sys.exc_info()[1])
        raise


def raise_catch_cy():
    try: raise ValueError
    except: pass

def raise_catch_cy_non_empty():
    try: raise ValueError
    except:
        a = 1+1



# cython: remove_unreachable=False
# mode: error

cdef object f(object x) nogil:
    pass

cdef void g(int x) nogil:
    cdef object z
    z = None

cdef void h(int x) nogil:
    p()

cdef object p() nogil:
    pass

cdef void r() nogil:
    q()

cdef object m():
    cdef object x, y = 0, obj
    cdef int i, j, k
    global fred
    q()
    with nogil:
        r()
        q()
        i = 42
        obj = None
        17L
        <object>7j
        help
        xxx = `"Hello"`
        import fred
        from fred import obj
        for x in obj:
            pass
        obj[i]
        obj[i:j]
        obj[i:j:k]
        obj.fred
        (x, y)
        [x, y]
        {x: y}
        {x, y}
        obj and x
        t(obj)
#        f(42) # Cython handles this internally
        x + obj
        -obj
        x = y = obj
        x, y = y, x
        obj[i] = x
        obj.fred = x
        print obj
        del fred
        return obj
        raise obj  # allowed!
        if obj:
            pass
        while obj:
            pass
        for x <= obj <= y:
            pass
        try:
            pass
        except:
            pass
        try:
            pass
        finally:
            pass

cdef void q():
    pass

cdef class C:
    pass

cdef void t(C c) nogil:
    pass

def ticket_338():
    cdef object obj
    with nogil:
        for obj from 0 <= obj < 4:
            pass

def bare_pyvar_name(object x):
    with nogil:
        x

# For m(), the important thing is that there are errors on all lines in the range 23-69
# except these: 29, 34, 44, 56, 58, 60, 62-64

_ERRORS = u"""
4:5: Function with Python return type cannot be declared nogil
7:5: Function declared nogil has Python locals or temporaries
9:4: Assignment of Python object not allowed without gil
12:5: Discarding owned Python object not allowed without gil
14:5: Function with Python return type cannot be declared nogil
18:5: Calling gil-requiring function not allowed without gil
27:9: Calling gil-requiring function not allowed without gil
29:8: Assignment of Python object not allowed without gil
31:16: Constructing complex number not allowed without gil
33:8: Assignment of Python object not allowed without gil
33:14: Backquote expression not allowed without gil
33:15: Operation not allowed without gil
34:15: Assignment of Python object not allowed without gil
34:15: Operation not allowed without gil
34:15: Python import not allowed without gil
35:8: Operation not allowed without gil
35:13: Python import not allowed without gil
35:25: Constructing Python list not allowed without gil
35:25: Operation not allowed without gil
36:17: Iterating over Python object not allowed without gil
38:11: Discarding owned Python object not allowed without gil
38:11: Indexing Python object not allowed without gil
39:11: Discarding owned Python object not allowed without gil
39:11: Slicing Python object not allowed without gil
40:11: Constructing Python slice object not allowed without gil
40:11: Discarding owned Python object not allowed without gil
40:11: Indexing Python object not allowed without gil
40:12: Converting to Python object not allowed without gil
40:14: Converting to Python object not allowed without gil
40:16: Converting to Python object not allowed without gil
41:11: Accessing Python attribute not allowed without gil
41:11: Discarding owned Python object not allowed without gil
42:9: Constructing Python tuple not allowed without gil
42:9: Discarding owned Python object not allowed without gil
43:8: Constructing Python list not allowed without gil
43:8: Discarding owned Python object not allowed without gil
44:9: Constructing Python dict not allowed without gil
44:9: Discarding owned Python object not allowed without gil
45:9: Constructing Python set not allowed without gil
45:9: Discarding owned Python object not allowed without gil
46:12: Discarding owned Python object not allowed without gil
46:12: Truth-testing Python object not allowed without gil
47:10: Python type test not allowed without gil
49:10: Discarding owned Python object not allowed without gil
49:10: Operation not allowed without gil
50:8: Discarding owned Python object not allowed without gil
50:8: Operation not allowed without gil
51:8: Assignment of Python object not allowed without gil
51:12: Assignment of Python object not allowed without gil
52:8: Assignment of Python object not allowed without gil
52:11: Assignment of Python object not allowed without gil
52:15: Creating temporary Python reference not allowed without gil
52:18: Creating temporary Python reference not allowed without gil
53:11: Assignment of Python object not allowed without gil
53:11: Indexing Python object not allowed without gil
54:11: Accessing Python attribute not allowed without gil
54:11: Assignment of Python object not allowed without gil
55:8: Constructing Python tuple not allowed without gil
55:8: Python print statement not allowed without gil
56:8: Deleting Python object not allowed without gil
57:8: Returning Python object not allowed without gil
59:11: Truth-testing Python object not allowed without gil
61:14: Truth-testing Python object not allowed without gil
63:8: For-loop using object bounds or target not allowed without gil
63:12: Coercion from Python not allowed without the GIL
63:24: Coercion from Python not allowed without the GIL
65:8: Try-except statement not allowed without gil
86:8: For-loop using object bounds or target not allowed without gil
"""



# Some comments first


# More comments

'A module docstring'

doctest = u"""# Python 3 gets all of these right ...
    >>> __doc__
    'A module docstring'

    >>> f.__doc__
    '\\n    This is a function docstring.\\n    '

    >>> C.__doc__
    '\\n    This is a class docstring.\\n    '
    >>> CS.__doc__
    '\\n    This is a subclass docstring.\\n    '
    >>> print(CSS.__doc__)
    None

    >>> T.__doc__
    '\\n    This is an extension type docstring.\\n    '
    >>> TS.__doc__
    '\\n    This is an extension subtype docstring.\\n    '
    >>> TSS.__doc__

Compare with standard Python:

    >>> def Pyf():
    ...     '''
    ...     This is a function docstring.
    ...     '''
    >>> Pyf.__doc__
    '\\n    This is a function docstring.\\n    '

    >>> class PyC:
    ...     '''
    ...     This is a class docstring.
    ...     '''
    >>> class PyCS(C):
    ...     '''
    ...     This is a subclass docstring.
    ...     '''
    >>> class PyCSS(CS):
    ...     pass

    >>> PyC.__doc__
    '\\n    This is a class docstring.\\n    '
    >>> PyCS.__doc__
    '\\n    This is a subclass docstring.\\n    '
    >>> PyCSS.__doc__
"""

__test__ = {"test_docstrings" : doctest}

def f():
    """
    This is a function docstring.
    """

class C:
    """
    This is a class docstring.
    """

class CS(C):
    """
    This is a subclass docstring.
    """

class CSS(CS):
    pass

cdef class T:
    """
    This is an extension type docstring.
    """

cdef class TS(T):
    """
    This is an extension subtype docstring.
    """

cdef class TSS(TS):
    pass


def n():
    "This is not a docstring".lower()

class PyN(object):
    u"This is not a docstring".lower()

cdef class CN(object):
    b"This is not a docstring".lower()


def test_non_docstrings():
    """
    >>> n.__doc__
    >>> PyN.__doc__
    >>> CN.__doc__
    """




cimport cython

cdef unicode _ustring = u'azerty123456'
ustring = _ustring


@cython.test_assert_path_exists("//CoerceToPyTypeNode",
                                "//IndexNode")
@cython.test_fail_if_path_exists("//IndexNode//CoerceToPyTypeNode")
def index(unicode ustring, Py_ssize_t i):
    """
    >>> index(ustring, 0) == 'a'
    True
    >>> index(ustring, 2) == 'e'
    True
    >>> index(ustring, -1) == '6'
    True
    >>> index(ustring, -len(ustring)) == 'a'
    True

    >>> index(ustring, len(ustring))
    Traceback (most recent call last):
    IndexError: string index out of range
    """
    return ustring[i]


@cython.test_assert_path_exists("//IndexNode")
@cython.test_fail_if_path_exists("//CoerceToPyTypeNode")
def index_pyindex(unicode ustring, i):
    """
    >>> index(ustring, 0) == 'a'
    True
    >>> index(ustring, 2) == 'e'
    True
    >>> index(ustring, -1) == '6'
    True
    >>> index(ustring, -len(ustring)) == 'a'
    True

    >>> index(ustring, len(ustring))
    Traceback (most recent call last):
    IndexError: string index out of range
    """
    return ustring[i]



@cython.test_assert_path_exists("//CoerceToPyTypeNode",
                                "//IndexNode")
@cython.test_fail_if_path_exists("//IndexNode//CoerceToPyTypeNode")
def index_literal(Py_ssize_t i):
    """
    >>> index_literal(0) == 'a'
    True
    >>> index_literal(2) == 'e'
    True
    >>> index_literal(-1) == '6'
    True
    >>> index_literal(-len('azerty123456')) == 'a'
    True

    >>> index_literal(len(ustring))
    Traceback (most recent call last):
    IndexError: string index out of range
    """
    return u'azerty123456'[i]


@cython.test_assert_path_exists("//IndexNode")
@cython.test_fail_if_path_exists("//IndexNode//CoerceToPyTypeNode")
def index_literal_pyunicode_cast(int i):
    """
    >>> index_literal_pyunicode_cast(0) == '1'
    True
    >>> index_literal_pyunicode_cast(-5) == '1'
    True
    >>> index_literal_pyunicode_cast(2) == '3'
    True
    >>> index_literal_pyunicode_cast(4) == '5'
    True
    >>> index_literal_pyunicode_coerce(6)
    Traceback (most recent call last):
    IndexError: string index out of range
    """
    return <Py_UNICODE>(u"12345"[i])


@cython.test_assert_path_exists("//IndexNode",
                                "//SingleAssignmentNode")
@cython.test_fail_if_path_exists("//SingleAssignmentNode//CoerceToPyTypeNode")
def index_literal_pyunicode_coerce(int i):
    """
    >>> index_literal_pyunicode_coerce(0) == '1'
    True
    >>> index_literal_pyunicode_coerce(-5) == '1'
    True
    >>> index_literal_pyunicode_coerce(2) == '3'
    True
    >>> index_literal_pyunicode_coerce(4) == '5'
    True
    >>> index_literal_pyunicode_coerce(6)
    Traceback (most recent call last):
    IndexError: string index out of range
    """
    cdef Py_UNICODE result = u"12345"[i]
    return result


@cython.test_assert_path_exists("//SingleAssignmentNode")
@cython.test_fail_if_path_exists("//SingleAssignmentNode//CoerceFromPyTypeNode")
@cython.boundscheck(False)
def index_literal_pyunicode_coerce_no_check(int i):
    """
    >>> index_literal_pyunicode_coerce_no_check(0) == '1'
    True
    >>> index_literal_pyunicode_coerce_no_check(-5) == '1'
    True
    >>> index_literal_pyunicode_coerce_no_check(2) == '3'
    True
    >>> index_literal_pyunicode_coerce_no_check(4) == '5'
    True
    """
    cdef Py_UNICODE result = u"12345"[i]
    return result


@cython.test_assert_path_exists("//CoerceToPyTypeNode",
                                "//IndexNode")
@cython.test_fail_if_path_exists("//IndexNode//CoerceToPyTypeNode")
@cython.boundscheck(False)
def index_no_boundscheck(unicode ustring, Py_ssize_t i):
    """
    >>> index_no_boundscheck(ustring, 0) == 'a'
    True
    >>> index_no_boundscheck(ustring, 2) == 'e'
    True
    >>> index_no_boundscheck(ustring, -1) == '6'
    True
    >>> index_no_boundscheck(ustring, len(ustring)-1) == '6'
    True
    >>> index_no_boundscheck(ustring, -len(ustring)) == 'a'
    True
    """
    return ustring[i]


@cython.test_assert_path_exists("//CoerceToPyTypeNode",
                                "//IndexNode")
@cython.test_fail_if_path_exists("//IndexNode//CoerceToPyTypeNode")
@cython.boundscheck(False)
def unsigned_index_no_boundscheck(unicode ustring, unsigned int i):
    """
    >>> unsigned_index_no_boundscheck(ustring, 0) == 'a'
    True
    >>> unsigned_index_no_boundscheck(ustring, 2) == 'e'
    True
    >>> unsigned_index_no_boundscheck(ustring, len(ustring)-1) == '6'
    True
    """
    return ustring[i]

@cython.test_assert_path_exists("//CoerceToPyTypeNode",
                                "//IndexNode",
                                "//PrimaryCmpNode")
@cython.test_fail_if_path_exists("//IndexNode//CoerceToPyTypeNode")
def index_compare(unicode ustring, Py_ssize_t i):
    """
    >>> index_compare(ustring, 0)
    True
    >>> index_compare(ustring, 1)
    False
    >>> index_compare(ustring, -1)
    False
    >>> index_compare(ustring, -len(ustring))
    True

    >>> index_compare(ustring, len(ustring))
    Traceback (most recent call last):
    IndexError: string index out of range
    """
    return ustring[i] == u'a'


@cython.test_assert_path_exists("//CoerceToPyTypeNode",
                                "//IndexNode",
                                "//PrimaryCmpNode")
@cython.test_fail_if_path_exists("//IndexNode//CoerceToPyTypeNode")
def index_compare_string(unicode ustring, Py_ssize_t i, unicode other):
    """
    >>> index_compare_string(ustring, 0, ustring[0])
    True
    >>> index_compare_string(ustring, 0, ustring[:4])
    False
    >>> index_compare_string(ustring, 1, ustring[0])
    False
    >>> index_compare_string(ustring, 1, ustring[1])
    True
    >>> index_compare_string(ustring, -1, ustring[0])
    False
    >>> index_compare_string(ustring, -1, ustring[-1])
    True
    >>> index_compare_string(ustring, -len(ustring), ustring[-len(ustring)])
    True

    >>> index_compare_string(ustring, len(ustring), ustring)
    Traceback (most recent call last):
    IndexError: string index out of range
    """
    return ustring[i] == other


@cython.test_assert_path_exists("//CoerceToPyTypeNode",
                                "//IndexNode",
                                "//MulNode",
                                "//MulNode/CoerceToPyTypeNode")
@cython.test_fail_if_path_exists("//IndexNode//CoerceToPyTypeNode")
def index_multiply(unicode ustring, Py_ssize_t i, int mul):
    """
    >>> ustring[0] * 5 == 'aaaaa'
    True
    >>> index_multiply(ustring, 0, 5) == 'aaaaa'
    True
    """
    return ustring[i] * mul


@cython.test_assert_path_exists("//CoerceToPyTypeNode",
                                "//IndexNode",
                                "//AddNode",
                                "//AddNode/CoerceToPyTypeNode")
@cython.test_fail_if_path_exists("//IndexNode//CoerceToPyTypeNode")
def index_add(unicode ustring, Py_ssize_t i, Py_ssize_t j):
    """
    >>> ustring[0] + ustring[-1] == 'a6'
    True
    >>> index_add(ustring, 0, -1) == 'a6'
    True
    """
    return ustring[i] + ustring[j]


@cython.test_assert_path_exists("//CoerceToPyTypeNode",
                                "//IndexNode",
                                "//CoerceToPyTypeNode//IndexNode")
@cython.test_fail_if_path_exists("//IndexNode//CoerceToPyTypeNode")
def index_concat_loop(unicode ustring):
    """
    >>> index_concat_loop(ustring) == ustring
    True
    """
    cdef int i
    cdef unicode s = u''
    for i in range(len(ustring)):
        s += ustring[i]
    return s


@cython.test_assert_path_exists("//CoerceToPyTypeNode",
                                "//IndexNode",
                                "//CoerceToPyTypeNode//IndexNode")
@cython.test_fail_if_path_exists("//IndexNode//CoerceToPyTypeNode")
def index_join_loop(unicode ustring):
    """
    >>> index_join_loop(ustring) == ustring
    True
    """
    cdef int i
    return u''.join([ ustring[i] for i in range(len(ustring)) ])



# mode: error
# tag: no-cpp, werror

from cython.operator import typeid

def use_typeid():
    cdef int i = 0
    print typeid(i) == typeid(i)

cdef cppclass A:
    pass

def use_new():
    cdef A* x = new A()

def use_del():
    cdef A a = A()
    cdef A *p = &a
    del p

_ERRORS = """
8:10: typeid operator only allowed in c++
8:23: typeid operator only allowed in c++
14:20: Operation only allowed in c++
19:4: Operation only allowed in c++
"""



t = (1,2,3)
l = [1,2,3]

def assign3(t):
    """
    >>> assign3(l)
    (1, 2, 3)
    >>> assign3(t)
    (1, 2, 3)
    >>> assign3((1,))
    Traceback (most recent call last):
    ValueError: need more than 1 value to unpack
    >>> assign3((1,2))
    Traceback (most recent call last):
    ValueError: need more than 2 values to unpack
    >>> assign3((1,2,3,4))
    Traceback (most recent call last):
    ValueError: too many values to unpack (expected 3)
    """
    a,b,c = t
    return (a,b,c)

def assign3_typed(tuple t):
    """
    >>> assign3_typed(t)
    (1, 2, 3)
    >>> assign3_typed(l)
    Traceback (most recent call last):
    TypeError: Argument 't' has incorrect type (expected tuple, got list)
    >>> a,b,c = (1,) # doctest: +ELLIPSIS
    Traceback (most recent call last):
    ValueError: ...
    >>> assign3_typed((1,))
    Traceback (most recent call last):
    ValueError: need more than 1 value to unpack
    >>> a,b,c = (1,2) # doctest: +ELLIPSIS
    Traceback (most recent call last):
    ValueError: ...
    >>> assign3_typed((1,2))
    Traceback (most recent call last):
    ValueError: need more than 2 values to unpack
    >>> a,b,c = (1,2,3,4)    # doctest: +ELLIPSIS
    Traceback (most recent call last):
    ValueError: ...
    >>> assign3_typed((1,2,3,4))
    Traceback (most recent call last):
    ValueError: too many values to unpack (expected 3)
    >>> a,b = 99,98
    >>> a,b = t     # doctest: +ELLIPSIS
    Traceback (most recent call last):
    ValueError: ...
    >>> a,b
    (99, 98)
    """
    a,b,c = t
    return (a,b,c)

def assign3_int(t):
    """
    >>> assign3_int(l)
    (1, 2, 3)
    """
    cdef int a,b,c
    a,b,c = t
    return (a,b,c)

def assign3_mixed1(t):
    """
    >>> assign3_mixed1(l)
    (1, 2, 3)
    """
    cdef int a
    a,b,c = t
    return (a,b,c)

def assign3_mixed2(t):
    """
    >>> assign3_mixed2(l)
    (1, 2, 3)
    """
    cdef int b
    a,b,c = t
    return (a,b,c)

def assign3_mixed3(t):
    """
    >>> assign3_mixed3(l)
    (1, 2, 3)
    """
    cdef int c
    a,b,c = t
    return (a,b,c)

def assign3_mixed4(t):
    cdef int b,c
    a,b,c = t
    return (a,b,c)

def test_overwrite(t):
    """
    >>> test_overwrite(l)
    (99, 98)
    >>> test_overwrite(t)
    (99, 98)
    """
    a,b = 99,98
    try:
        a,b = t
    except ValueError:
        pass
    return (a,b)

def test_overwrite_int(t):
    """
    >>> test_overwrite_int(l)
    (99, 98)
    >>> test_overwrite_int(t)
    (99, 98)
    """
    cdef int a,b
    a,b = 99,98
    try:
        a,b = t
    except ValueError:
        pass
    return (a,b)

def test_overwrite_mixed(t):
    """
    >>> test_overwrite_mixed(l)
    (99, 98)
    >>> test_overwrite_mixed(t)
    (99, 98)
    """
    cdef int b
    a,b = 99,98
    try:
        a,b = t
    except ValueError:
        pass
    return (a,b)

def test_overwrite_mixed2(t):
    """
    >>> test_overwrite_mixed2(l)
    (99, 98)
    >>> test_overwrite_mixed2(t)
    (99, 98)
    """
    cdef int a
    a,b = 99,98
    try:
        a,b = t
    except ValueError:
        pass
    return (a,b)



# mode: run

cimport cython


def bigint(x):
    # avoid 'L' postfix in Py2.x
    print(str(x).rstrip('L'))

def bigints(x):
    # avoid 'L' postfix in Py2.x
    print(str(x).replace('L', ''))


@cython.test_assert_path_exists('//IntBinopNode')
def or_obj(obj2, obj3):
    """
    >>> or_obj(2, 3)
    3
    """
    obj1 = obj2 | obj3
    return obj1


@cython.test_fail_if_path_exists('//IntBinopNode')
def or_int(obj2):
    """
    >>> or_int(1)
    17
    >>> or_int(16)
    16
    """
    obj1 = obj2 | 0x10
    return obj1


@cython.test_assert_path_exists('//IntBinopNode')
def xor_obj(obj2, obj3):
    """
    >>> xor_obj(2, 3)
    1
    """
    obj1 = obj2 ^ obj3
    return obj1


@cython.test_fail_if_path_exists('//IntBinopNode')
def xor_int(obj2):
    """
    >>> xor_int(2)
    18
    >>> xor_int(16)
    0
    """
    obj1 = obj2 ^ 0x10
    return obj1


@cython.test_assert_path_exists('//IntBinopNode')
def and_obj(obj2, obj3):
    """
    >>> and_obj(2, 3)
    2
    """
    obj1 = obj2 & obj3
    return obj1


@cython.test_fail_if_path_exists('//IntBinopNode')
def and_int(obj2):
    """
    >>> and_int(1)
    0
    >>> and_int(18)
    16
    """
    obj1 = obj2 & 0x10
    return obj1


@cython.test_assert_path_exists('//IntBinopNode')
def lshift_obj(obj2, obj3):
    """
    >>> lshift_obj(2, 3)
    16
    """
    obj1 = obj2 << obj3
    return obj1


@cython.test_assert_path_exists('//IntBinopNode')
def rshift_obj(obj2, obj3):
    """
    >>> rshift_obj(2, 3)
    0
    """
    obj1 = obj2 >> obj3
    return obj1


@cython.test_fail_if_path_exists('//IntBinopNode')
def rshift_int(obj2):
    """
    >>> rshift_int(2)
    0

    >>> rshift_int(27)
    3
    >>> (-27) >> 3
    -4
    >>> rshift_int(-27)
    -4

    >>> rshift_int(32)
    4
    >>> (-32) >> 3
    -4
    >>> rshift_int(-32)
    -4

    >>> (2**28) >> 3
    33554432
    >>> rshift_int(2**28)
    33554432
    >>> (-2**28) >> 3
    -33554432
    >>> rshift_int(-2**28)
    -33554432

    >>> (2**30) >> 3
    134217728
    >>> rshift_int(2**30)
    134217728
    >>> rshift_int(-2**30)
    -134217728

    >>> bigint((2**60) >> 3)
    144115188075855872
    >>> bigint(rshift_int(2**60))
    144115188075855872
    >>> bigint(rshift_int(-2**60))
    -144115188075855872
    """
    obj1 = obj2 >> 3
    return obj1


@cython.test_assert_path_exists(
    '//SingleAssignmentNode//IntBinopNode',
    '//SingleAssignmentNode//PythonCapiCallNode',
)
def lshift_int(obj):
    """
    >>> lshift_int(0)
    (0, 0, 0, 0)
    >>> bigints(lshift_int(1))
    (8, 2147483648, 9223372036854775808, 10633823966279326983230456482242756608)
    >>> bigints(lshift_int(-1))
    (-8, -2147483648, -9223372036854775808, -10633823966279326983230456482242756608)
    >>> bigints(lshift_int(2))
    (16, 4294967296, 18446744073709551616, 21267647932558653966460912964485513216)

    >>> bigints(lshift_int(27))
    (216, 57982058496, 249031044995078946816, 287113247089541828547222325020554428416)
    >>> (-27) << 3
    -216
    >>> bigints(lshift_int(-27))
    (-216, -57982058496, -249031044995078946816, -287113247089541828547222325020554428416)

    >>> bigints(lshift_int(32))
    (256, 68719476736, 295147905179352825856, 340282366920938463463374607431768211456)
    >>> (-32) << 3
    -256
    >>> bigints(lshift_int(-32))
    (-256, -68719476736, -295147905179352825856, -340282366920938463463374607431768211456)

    >>> bigint((2**28) << 3)
    2147483648
    >>> bigints(lshift_int(2**28))
    (2147483648, 576460752303423488, 2475880078570760549798248448, 2854495385411919762116571938898990272765493248)
    >>> bigint((-2**28) << 3)
    -2147483648
    >>> bigints(lshift_int(-2**28))
    (-2147483648, -576460752303423488, -2475880078570760549798248448, -2854495385411919762116571938898990272765493248)

    >>> bigint((2**30) << 3)
    8589934592
    >>> bigints(lshift_int(2**30))
    (8589934592, 2305843009213693952, 9903520314283042199192993792, 11417981541647679048466287755595961091061972992)
    >>> bigints(lshift_int(-2**30))
    (-8589934592, -2305843009213693952, -9903520314283042199192993792, -11417981541647679048466287755595961091061972992)

    >>> bigint((2**60) << 3)
    9223372036854775808
    >>> bigints(lshift_int(2**60))
    (9223372036854775808, 2475880078570760549798248448, 10633823966279326983230456482242756608, 12259964326927110866866776217202473468949912977468817408)
    >>> bigints(lshift_int(-2**60))
    (-9223372036854775808, -2475880078570760549798248448, -10633823966279326983230456482242756608, -12259964326927110866866776217202473468949912977468817408)
    """
    r1 = obj << 3
    r2 = obj << 31
    r3 = obj << 63
    r4 = obj << 123
    return r1, r2, r3, r4


@cython.test_assert_path_exists(
    '//IntBinopNode',
    '//IntBinopNode//IntBinopNode',
)
def mixed_obj(obj2, obj3):
    """
    >>> mixed_obj(2, 3)
    16
    """
    obj1 = obj2 << obj3 | obj2 >> obj3
    return obj1


@cython.test_assert_path_exists(
    '//IntBinopNode',
    '//IntBinopNode//PythonCapiCallNode',
)
@cython.test_fail_if_path_exists(
    '//IntBinopNode//IntBinopNode',
)
def mixed_int(obj2):
    """
    >>> mixed_int(2)
    18
    >>> mixed_int(16)
    0
    >>> mixed_int(17)
    1
    """
    obj1 = (obj2 ^ 0x10) | (obj2 & 0x01)
    return obj1


@cython.test_assert_path_exists('//PythonCapiCallNode')
@cython.test_fail_if_path_exists(
    '//IntBinopNode',
    '//PrimaryCmpNode',
)
def equals(obj2):
    """
    >>> equals(2)
    True
    >>> equals(0)
    False
    >>> equals(-1)
    False
    """
    result = obj2 == 2
    return result


@cython.test_assert_path_exists('//PythonCapiCallNode')
@cython.test_fail_if_path_exists(
    '//IntBinopNode',
    '//PrimaryCmpNode',
)
def not_equals(obj2):
    """
    >>> not_equals(2)
    False
    >>> not_equals(0)
    True
    >>> not_equals(-1)
    True
    """
    result = obj2 != 2
    return result


@cython.test_assert_path_exists('//PythonCapiCallNode')
@cython.test_assert_path_exists('//PrimaryCmpNode')
def equals_many(obj2):
    """
    >>> equals_many(-2)
    (False, False, False, False, False, False, False, False, False, False, False, False, False, False, False)
    >>> equals_many(0)
    (True, False, False, False, False, False, False, False, False, False, False, False, False, False, False)
    >>> equals_many(1)
    (False, True, False, False, False, False, False, False, False, False, False, False, False, False, False)
    >>> equals_many(-1)
    (False, False, True, False, False, False, False, False, False, False, False, False, False, False, False)
    >>> equals_many(2**30)
    (False, False, False, True, False, False, False, False, False, False, False, False, False, False, False)
    >>> equals_many(-2**30)
    (False, False, False, False, True, False, False, False, False, False, False, False, False, False, False)
    >>> equals_many(2**30-1)
    (False, False, False, False, False, True, False, False, False, False, False, False, False, False, False)
    >>> equals_many(-2**30+1)
    (False, False, False, False, False, False, True, False, False, False, False, False, False, False, False)
    >>> equals_many(2**32)
    (False, False, False, False, False, False, False, True, False, False, False, False, False, False, False)
    >>> equals_many(-2**32)
    (False, False, False, False, False, False, False, False, True, False, False, False, False, False, False)
    >>> equals_many(2**45-1)
    (False, False, False, False, False, False, False, False, False, True, False, False, False, False, False)
    >>> equals_many(-2**45+1)
    (False, False, False, False, False, False, False, False, False, False, True, False, False, False, False)
    >>> equals_many(2**64)
    (False, False, False, False, False, False, False, False, False, False, False, True, False, False, False)
    >>> equals_many(-2**64)
    (False, False, False, False, False, False, False, False, False, False, False, False, True, False, False)
    >>> equals_many(2**64-1)
    (False, False, False, False, False, False, False, False, False, False, False, False, False, True, False)
    >>> equals_many(-2**64+1)
    (False, False, False, False, False, False, False, False, False, False, False, False, False, False, True)
    """
    cdef bint x, a, b, c, d, e, f, g, h, i, j, k, l, m, n, o
    a = obj2 == 0
    x = 0 == obj2
    assert a == x
    b = obj2 == 1
    x = 1 == obj2
    assert b == x
    c = obj2 == -1
    x = -1 == obj2
    assert c == x
    d = obj2 == 2**30
    x = 2**30 == obj2
    assert d == x
    e = obj2 == -2**30
    x = -2**30 == obj2
    assert e == x
    f = obj2 == 2**30-1
    x = 2**30-1 == obj2
    assert f == x
    g = obj2 == -2**30+1
    x = -2**30+1 == obj2
    assert g == x
    h = obj2 == 2**32
    x = 2**32 == obj2
    assert h == x
    i = obj2 == -2**32
    x = -2**32 == obj2
    assert i == x
    j = obj2 == 2**45-1
    x = 2**45-1 == obj2
    assert j == x
    k = obj2 == -2**45+1
    x = -2**45+1 == obj2
    assert k == x
    l = obj2 == 2**64
    x = 2**64 == obj2
    assert l == x
    m = obj2 == -2**64
    x = -2**64 == obj2
    assert m == x
    n = obj2 == 2**64-1
    x = 2**64-1 == obj2
    assert n == x
    o = obj2 == -2**64+1
    x = -2**64+1 == obj2
    assert o == x
    return (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o)


@cython.test_assert_path_exists('//PythonCapiCallNode')
@cython.test_assert_path_exists('//PrimaryCmpNode')
def not_equals_many(obj2):
    """
    >>> not_equals_many(-2)
    (False, False, False, False, False, False, False, False, False, False, False, False, False, False, False)
    >>> not_equals_many(0)
    (True, False, False, False, False, False, False, False, False, False, False, False, False, False, False)
    >>> not_equals_many(1)
    (False, True, False, False, False, False, False, False, False, False, False, False, False, False, False)
    >>> not_equals_many(-1)
    (False, False, True, False, False, False, False, False, False, False, False, False, False, False, False)
    >>> not_equals_many(2**30)
    (False, False, False, True, False, False, False, False, False, False, False, False, False, False, False)
    >>> not_equals_many(-2**30)
    (False, False, False, False, True, False, False, False, False, False, False, False, False, False, False)
    >>> not_equals_many(2**30-1)
    (False, False, False, False, False, True, False, False, False, False, False, False, False, False, False)
    >>> not_equals_many(-2**30+1)
    (False, False, False, False, False, False, True, False, False, False, False, False, False, False, False)
    >>> not_equals_many(2**32)
    (False, False, False, False, False, False, False, True, False, False, False, False, False, False, False)
    >>> not_equals_many(-2**32)
    (False, False, False, False, False, False, False, False, True, False, False, False, False, False, False)
    >>> not_equals_many(2**45-1)
    (False, False, False, False, False, False, False, False, False, True, False, False, False, False, False)
    >>> not_equals_many(-2**45+1)
    (False, False, False, False, False, False, False, False, False, False, True, False, False, False, False)
    >>> not_equals_many(2**64)
    (False, False, False, False, False, False, False, False, False, False, False, True, False, False, False)
    >>> not_equals_many(-2**64)
    (False, False, False, False, False, False, False, False, False, False, False, False, True, False, False)
    >>> not_equals_many(2**64-1)
    (False, False, False, False, False, False, False, False, False, False, False, False, False, True, False)
    >>> not_equals_many(-2**64+1)
    (False, False, False, False, False, False, False, False, False, False, False, False, False, False, True)
    """
    cdef bint a, b, c, d, e, f, g, h, i, j, k, l, m, n, o
    a = obj2 != 0
    x = 0 != obj2
    assert a == x
    b = obj2 != 1
    x = 1 != obj2
    assert b == x
    c = obj2 != -1
    x = -1 != obj2
    assert c == x
    d = obj2 != 2**30
    x = 2**30 != obj2
    assert d == x
    e = obj2 != -2**30
    x = -2**30 != obj2
    assert e == x
    f = obj2 != 2**30-1
    x = 2**30-1 != obj2
    assert f == x
    g = obj2 != -2**30+1
    x = -2**30+1 != obj2
    assert g == x
    h = obj2 != 2**32
    x = 2**32 != obj2
    assert h == x
    i = obj2 != -2**32
    x = -2**32 != obj2
    assert i == x
    j = obj2 != 2**45-1
    x = 2**45-1 != obj2
    assert j == x
    k = obj2 != -2**45+1
    x = -2**45+1 != obj2
    assert k == x
    l = obj2 != 2**64
    x = 2**64 != obj2
    assert l == x
    m = obj2 != -2**64
    x = -2**64 != obj2
    assert m == x
    n = obj2 != 2**64-1
    x = 2**64-1 != obj2
    assert n == x
    o = obj2 != -2**64+1
    x = -2**64+1 != obj2
    assert o == x
    return tuple(not x for x in (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o))


@cython.test_assert_path_exists('//PythonCapiCallNode')
@cython.test_fail_if_path_exists(
    '//IntBinopNode',
    '//PrimaryCmpNode',
)
def equals_zero(obj2):
    """
    >>> equals_zero(2)
    False
    >>> equals_zero(0)
    True
    >>> equals_zero(-1)
    False
    """
    result = obj2 == 0
    return result


def truthy(obj2):
    """
    >>> truthy(2)
    True
    >>> truthy(0)
    False
    >>> truthy(-1)
    True
    """
    if obj2:
        return True
    else:
        return False



# tag: warnings

cpdef str a = "123"
cpdef b = 2

cdef class C:
    cpdef float c

def func():
    """
    >>> c = func()
    >>> isinstance(c, C) or c
    True
    """
    cpdef d = C()
    return d


_WARNINGS = """
3:6: cpdef variables will not be supported in Cython 3; currently they are no different from cdef variables
4:6: cpdef variables will not be supported in Cython 3; currently they are no different from cdef variables
7:10: cpdef variables will not be supported in Cython 3; currently they are no different from cdef variables
15:10: cpdef variables will not be supported in Cython 3; currently they are no different from cdef variables
"""




# deprecated cimport for backwards compatibility:
from libc.string cimport const_char

cdef extern from "<string>" namespace "std::string" nogil:
    const size_t npos

cdef extern from "<string>" namespace "std" nogil:
    cdef cppclass string:

        cppclass iterator:
            iterator()
            char& operator*()
            iterator(iterator&)
            iterator operator++()
            iterator operator--()
            bint operator==(iterator)
            bint operator!=(iterator)

        cppclass reverse_iterator:
            char& operator*()
            iterator operator++()
            iterator operator--()
            iterator operator+(size_t)
            iterator operator-(size_t)
            bint operator==(reverse_iterator)
            bint operator!=(reverse_iterator)
            bint operator<(reverse_iterator)
            bint operator>(reverse_iterator)
            bint operator<=(reverse_iterator)
            bint operator>=(reverse_iterator)

        cppclass const_iterator(iterator):
            pass

        cppclass const_reverse_iterator(reverse_iterator):
            pass

        string() except +
        string(const string& s) except +
        string(const string& s, size_t pos) except +
        string(const string& s, size_t pos, size_t len) except +
        string(const char* s) except +
        string(const char* s, size_t n) except +
        string(size_t n, char c) except +
        string(iterator first, iterator last) except +

        iterator begin()
        const_iterator const_begin "begin"()
        iterator end()
        const_iterator const_end "end"()
        reverse_iterator rbegin()
        const_reverse_iterator const_rbegin "rbegin"()
        reverse_iterator rend()
        const_reverse_iterator const_rend "rend"()

        const char* c_str()
        const char* data()
        size_t size()
        size_t max_size()
        size_t length()
        void resize(size_t) except +
        void resize(size_t, char) except +
        void shrink_to_fit() except +
        size_t capacity()
        void reserve(size_t) except +
        void clear()
        bint empty()

        iterator erase(iterator first, iterator last)
        iterator erase(iterator p)
        iterator erase(const_iterator first, const_iterator last)
        iterator erase(const_iterator p)
        string& erase(size_t pos, size_t len) except +
        string& erase(size_t pos) except +
        string& erase() except +

        char& at(size_t pos) except +
        char& operator[](size_t pos)
        char& front()
        char& back()
        int compare(const string& s)
        int compare(size_t pos, size_t len, const string& s) except +
        int compare(size_t pos, size_t len, const string& s, size_t subpos, size_t sublen) except +
        int compare(const char* s) except +
        int compare(size_t pos, size_t len, const char* s) except +
        int compare(size_t pos, size_t len, const char* s , size_t n) except +

        string& append(const string& s) except +
        string& append(const string& s, size_t subpos, size_t sublen) except +
        string& append(const char* s) except +
        string& append(const char* s, size_t n) except +
        string& append(size_t n, char c) except +

        void push_back(char c) except +
        void pop_back()

        string& assign(const string& s) except +
        string& assign(const string& s, size_t subpos, size_t sublen) except +
        string& assign(const char* s, size_t n) except +
        string& assign(const char* s) except +
        string& assign(size_t n, char c) except +

        string& insert(size_t pos, const string& s, size_t subpos, size_t sublen) except +
        string& insert(size_t pos, const string& s) except +
        string& insert(size_t pos, const char* s, size_t n) except +
        string& insert(size_t pos, const char* s) except +
        string& insert(size_t pos, size_t n, char c) except +
        void insert(iterator p, size_t n, char c) except +
        iterator insert(iterator p, char c) except +

        size_t copy(char* s, size_t len, size_t pos) except +
        size_t copy(char* s, size_t len) except +

        size_t find(const string& s, size_t pos)
        size_t find(const string& s)
        size_t find(const char* s, size_t pos, size_t n)
        size_t find(const char* s, size_t pos)
        size_t find(const char* s)
        size_t find(char c, size_t pos)
        size_t find(char c)

        size_t rfind(const string&, size_t pos)
        size_t rfind(const string&)
        size_t rfind(const char* s, size_t pos, size_t n)
        size_t rfind(const char* s, size_t pos)
        size_t rfind(const char* s)
        size_t rfind(char c, size_t pos)
        size_t rfind(char c)

        size_t find_first_of(const string&, size_t pos)
        size_t find_first_of(const string&)
        size_t find_first_of(const char* s, size_t pos, size_t n)
        size_t find_first_of(const char* s, size_t pos)
        size_t find_first_of(const char* s)
        size_t find_first_of(char c, size_t pos)
        size_t find_first_of(char c)

        size_t find_first_not_of(const string& s, size_t pos)
        size_t find_first_not_of(const string& s)
        size_t find_first_not_of(const char* s, size_t pos, size_t n)
        size_t find_first_not_of(const char* s, size_t pos)
        size_t find_first_not_of(const char*)
        size_t find_first_not_of(char c, size_t pos)
        size_t find_first_not_of(char c)

        size_t find_last_of(const string& s, size_t pos)
        size_t find_last_of(const string& s)
        size_t find_last_of(const char* s, size_t pos, size_t n)
        size_t find_last_of(const char* s, size_t pos)
        size_t find_last_of(const char* s)
        size_t find_last_of(char c, size_t pos)
        size_t find_last_of(char c)

        size_t find_last_not_of(const string& s, size_t pos)
        size_t find_last_not_of(const string& s)
        size_t find_last_not_of(const char* s, size_t pos, size_t n)
        size_t find_last_not_of(const char* s, size_t pos)
        size_t find_last_not_of(const char* s)
        size_t find_last_not_of(char c, size_t pos)
        size_t find_last_not_of(char c)

        string substr(size_t pos, size_t len) except +
        string substr(size_t pos) except +
        string substr()

        #string& operator= (const string&)
        #string& operator= (const char*)
        #string& operator= (char)

        string operator+ (const string&) except +
        string operator+ (const char*) except +

        bint operator==(const string&)
        bint operator==(const char*)

        bint operator!= (const string&)
        bint operator!= (const char*)

        bint operator< (const string&)
        bint operator< (const char*)

        bint operator> (const string&)
        bint operator> (const char*)

        bint operator<= (const string&)
        bint operator<= (const char*)

        bint operator>= (const string&)
        bint operator>= (const char*)


    string to_string(int val) except +
    string to_string(long val) except +
    string to_string(long long val) except +
    string to_string(unsigned val) except +
    string to_string(size_t val) except +
    string to_string(ssize_t val) except +
    string to_string(unsigned long val) except +
    string to_string(unsigned long long val) except +
    string to_string(float val) except +
    string to_string(double val) except +
    string to_string(long double val) except +

    int stoi(const string& s, size_t* idx, int base) except +
    int stoi(const string& s, size_t* idx) except +
    int stoi(const string& s) except +
    long stol(const string& s, size_t* idx, int base) except +
    long stol(const string& s, size_t* idx) except +
    long stol(const string& s) except +
    long long stoll(const string& s, size_t* idx, int base) except +
    long long stoll(const string& s, size_t* idx) except +
    long long stoll(const string& s) except +

    unsigned long stoul(const string& s, size_t* idx, int base) except +
    unsigned long stoul(const string& s, size_t* idx) except +
    unsigned long stoul(const string& s) except +
    unsigned long long stoull(const string& s, size_t* idx, int base) except +
    unsigned long long stoull(const string& s, size_t* idx) except +
    unsigned long long stoull(const string& s) except +

    float stof(const string& s, size_t* idx) except +
    float stof(const string& s) except +
    double stod(const string& s, size_t* idx) except +
    double stod(const string& s) except +
    long double stold(const string& s, size_t* idx) except +
    long double stold(const string& s) except +



# mode: compile

"""A long module docstring.

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer sit amet
mauris mauris, sit amet venenatis nisl. Vivamus a est porta enim sollicitudin
mollis. Proin fringilla massa vel ante gravida luctus. Nunc quis nunc id quam
hendrerit posuere. Cum sociis natoque penatibus et magnis dis parturient
montes, nascetur ridiculus mus. Aliquam porttitor interdum sollicitudin. Mauris
malesuada tellus tellus. Mauris condimentum nunc et sapien pellentesque
gravida. Suspendisse sed ipsum orci. Duis ut lacus dui. Integer ac gravida sem.
Vivamus fermentum porttitor velit ac blandit. Maecenas pulvinar ullamcorper
enim, vitae aliquet tortor scelerisque et. Vestibulum ante massa, sodales et
bibendum dignissim, consectetur vitae metus. Quisque vel dui erat, vel commodo
metus. Aliquam arcu dolor, viverra sit amet porttitor a, faucibus eu augue.

Sed ornare, enim eget ultricies suscipit, nunc dui lacinia enim, vitae tempus
nunc libero vitae ligula. Nam et commodo ligula. Pellentesque tincidunt lorem
at elit aliquam at fringilla libero tempor. Donec molestie consectetur nibh, ac
varius ante dictum id. Suspendisse lectus nibh, molestie vel dapibus eget,
egestas ut eros. Mauris vel mauris turpis, vitae bibendum nunc. Vestibulum
nulla enim, vestibulum vitae tincidunt et, gravida eu metus. Nulla sagittis,
odio a placerat laoreet, arcu lectus vestibulum nunc, in hendrerit tortor quam
sit amet turpis. In et purus vel dui pellentesque tincidunt. Donec dictum nibh
sed quam luctus sit amet luctus justo dapibus. Integer nulla elit, lacinia
aliquet euismod sed, tempus vitae lectus. Fusce non sapien dolor. Suspendisse
ut est ut dui tempor ultricies id ut elit. Aenean adipiscing sollicitudin enim,
nec porttitor est porttitor eget. Proin lobortis ante ut diam sodales volutpat.
Donec urna diam, porttitor nec laoreet ut, rhoncus non diam.

Ut sed mi vitae turpis semper semper. Integer sit amet lorem sapien. Aliquam
risus diam, vulputate id sagittis et, molestie ut lectus. Aliquam erat
volutpat. Morbi aliquet venenatis metus in posuere. Cras vitae purus nunc, ut
vestibulum ipsum. Nullam vehicula dui in urna iaculis lobortis. Ut a est non
est tincidunt iaculis. Vivamus rutrum velit non nunc malesuada sed bibendum mi
iaculis. Sed id lacus in sem tempor vestibulum. Cras bibendum accumsan
suscipit. Phasellus congue nisl consectetur turpis rhoncus aliquet posuere
libero fringilla. Sed eros tellus, hendrerit nec imperdiet vitae, blandit ac
dolor. Nulla facilisi. Morbi ullamcorper libero odio, at cursus tortor. Cras
ultricies tellus eget justo cursus cursus. Donec at mi massa, auctor suscipit
sem.

Proin dolor purus, semper sed ultrices ut, iaculis at tortor. Donec risus enim,
interdum et convallis nec, aliquam eget velit. Curabitur eget lectus dolor.
Integer id turpis eu nulla euismod tincidunt. Fusce elit nibh, dapibus sit amet
tempus ac, convallis eu libero. Donec dui justo, molestie sed euismod porta,
ultricies id orci. Praesent a tellus et risus faucibus porttitor pellentesque
in purus. Fusce blandit risus ac tortor viverra vitae molestie odio convallis.
Donec rhoncus volutpat mauris, sit amet mattis libero dapibus id. Ut rhoncus
venenatis nisi ac dictum. In non nulla eget massa convallis facilisis. Praesent
nec odio id odio semper lobortis non eu erat. Proin quis gravida magna. Sed
rhoncus lectus auctor arcu posuere a auctor dui pellentesque.

Sed enim nulla, luctus quis sagittis sed, vestibulum eget metus. Mauris ornare
pretium fringilla. Proin ligula eros, fermentum in placerat sit amet, placerat
vel mauris. Nulla magna enim, luctus eget euismod ac, lacinia vel lorem. Duis
mi leo, porttitor vitae dictum ac, ultrices iaculis metus. Quisque libero mi,
aliquet quis vestibulum eget, porttitor non justo. Praesent ac metus felis.
Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac
turpis egestas. Donec vel enim sit amet ante imperdiet commodo sed vel nisi.
Praesent semper viverra nulla vehicula sollicitudin. Fusce lacinia aliquet
ullamcorper. Donec vitae diam est. Integer volutpat hendrerit turpis ut
bibendum. Integer et dui augue.

Nunc ut nisl in felis feugiat semper nec sit amet purus. Proin convallis
ultrices nisl ut vehicula. Pellentesque neque mi, elementum vel placerat nec,
laoreet ac nulla. Pellentesque aliquam dui a metus iaculis posuere. Curabitur
dapibus faucibus metus. Donec quis diam dui. Proin at mi nec augue cursus
pulvinar eu vel metus. Curabitur eget turpis ac risus dignissim luctus sed id
ligula. Etiam lectus neque, varius ut euismod nec, euismod quis nulla. Ut
feugiat, quam id tempor luctus, metus eros lacinia diam, nec dapibus tellus dui
quis diam. Nam interdum, orci id fringilla mattis, ipsum eros pellentesque
turpis, hendrerit dignissim justo dui interdum ante. Curabitur aliquam nisi ut
dui lacinia tempor. Nulla lobortis tellus non sapien dignissim ut dapibus dui
aliquet. Nam scelerisque, urna a aliquam malesuada, mi tortor scelerisque
libero, quis pellentesque erat eros ut justo.

Phasellus nulla purus, suscipit vel gravida euismod, malesuada et odio.
Vestibulum non libero eget lacus venenatis auctor quis a est. Nunc id leo est.
Curabitur pulvinar viverra sapien at viverra. Cras pretium justo et lorem
lobortis id tempor nisi accumsan. Cras egestas tortor in risus hendrerit eu
varius purus suscipit. Nullam mauris eros, mattis at tempor vitae, mollis vitae
velit. Etiam at adipiscing lectus. Quisque molestie, metus id posuere pharetra,
lorem enim vehicula mauris, ut ultricies purus justo a lacus. Vivamus blandit
euismod adipiscing. Nam eu ligula at elit ultricies tempus. Nunc ac sodales
neque. Ut dui diam, porttitor a pulvinar vel, sodales sit amet turpis. Donec
vitae eros at neque luctus scelerisque. In consequat elementum iaculis. Donec
ullamcorper dolor eu quam volutpat rhoncus. Lorem ipsum dolor sit amet,
consectetur adipiscing elit. Cras laoreet ante eget dolor sagittis imperdiet.
Proin magna urna, porta id blandit nec, commodo eget lorem.

Etiam imperdiet, orci sit amet rutrum consectetur, orci augue tempus lacus, id
venenatis sapien nisl a est. Sed accumsan massa sed libero consectetur
scelerisque. Class aptent taciti sociosqu ad litora torquent per conubia
nostra, per inceptos himenaeos. Sed nunc risus, lobortis id egestas nec,
suscipit id magna. Morbi at iaculis mauris. Proin felis sem, tempus non
pellentesque congue, vehicula sit amet eros. Maecenas porttitor erat ac dolor
pharetra iaculis. Cras tincidunt, nulla eget malesuada egestas, sem diam
consequat quam, sed feugiat nulla orci at mauris. Quisque non arcu diam, ac
lacinia felis. Nunc iaculis mollis egestas. Etiam imperdiet dolor consectetur
eros feugiat fringilla sed in lacus. Nunc nec tincidunt dolor. Etiam sagittis
tortor condimentum nunc fermentum vestibulum. Vivamus lobortis, magna sit amet
scelerisque lobortis, sem eros molestie leo, eget aliquet ligula est in lectus.
Duis placerat porta pulvinar. Sed sed adipiscing ante. Vestibulum ante ipsum
primis in faucibus orci luctus et ultrices posuere cubilia Curae; Nam accumsan
iaculis augue, sed varius dui sagittis id. Etiam sit amet eleifend augue.

Ut sit amet nibh sit amet justo tempor condimentum. Ut faucibus sagittis
volutpat. Duis vestibulum feugiat sollicitudin. Aenean cursus luctus urna at
consectetur. Nullam tincidunt, eros a iaculis sodales, tellus est imperdiet
arcu, sit amet tincidunt orci felis et tortor. Mauris rutrum venenatis nunc ut
rutrum. Phasellus nec erat magna, in tincidunt orci. Sed sit amet suscipit
tellus. Mauris ut nisi turpis. Suspendisse augue turpis, condimentum ac
bibendum in, vestibulum nec eros. Curabitur dapibus pulvinar vehicula. Fusce
consequat, erat in malesuada hendrerit, tellus urna pharetra lacus, sed euismod
nisi urna sed nisi. Etiam fermentum accumsan nunc, sed bibendum dui iaculis id.
Etiam blandit fermentum ligula nec viverra. Vivamus venenatis arcu in nulla
euismod euismod. Donec sit amet augue nec metus varius fringilla. Vivamus
pulvinar elit ac mi rhoncus in luctus diam egestas. Curabitur a felis eget arcu
pretium tempus eu sed mauris. Vestibulum ante ipsum primis in faucibus orci
luctus et ultrices posuere cubilia Curae;

Mauris malesuada, nibh ac venenatis hendrerit, ligula dui condimentum tellus,
sit amet pretium diam tortor vel risus. Suspendisse suscipit consequat eros id
dignissim. Cras interdum lorem ac massa euismod non porta enim pretium. Aliquam
ultrices nibh vitae ligula consectetur vel sollicitudin lacus volutpat.
Phasellus vulputate iaculis sem nec laoreet. Nam leo sem, tempor eu condimentum
id, imperdiet sed dolor. Donec pharetra velit non libero euismod tempor.
Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere
cubilia Curae; Sed fermentum, libero a posuere posuere, enim elit imperdiet
enim, a sollicitudin est felis non libero. Sed vel dolor ut arcu dapibus
iaculis nec a mauris. Morbi ullamcorper ultrices venenatis. Fusce luctus ante
sit amet lacus venenatis ut rutrum elit lobortis. Nulla fermentum tortor ac
sapien fringilla quis iaculis quam egestas.

Aliquam et tortor est, at elementum mauris. Morbi posuere erat nec leo
vulputate in pellentesque tortor condimentum. Vestibulum at orci augue. Aenean
pellentesque sapien id felis consequat varius. Suspendisse bibendum enim sit
amet mi imperdiet vel suscipit nisi tristique. Curabitur velit massa,
consectetur ac mattis vel, accumsan at nunc. Donec porta, nibh nec consequat
convallis, urna neque auctor erat, eu convallis lorem leo convallis turpis.
Morbi non mauris non metus ornare vulputate. Sed aliquet, dolor ut egestas
fermentum, metus purus mollis elit, nec commodo odio quam quis nisl. Aliquam
erat volutpat. Suspendisse sed faucibus urna. Integer suscipit rutrum
condimentum. Praesent dignissim libero eget metus luctus consectetur.

Vestibulum ac erat felis, vitae iaculis erat. Duis interdum lacinia arcu, non
lacinia urna luctus in. Curabitur feugiat sapien sapien, in vestibulum diam.
Phasellus lobortis massa ut metus pretium dignissim. Fusce quis sem odio.
Integer pellentesque sodales augue id tincidunt. Pellentesque habitant morbi
tristique senectus et netus et malesuada fames ac turpis egestas. Vestibulum
lorem odio, semper vel scelerisque sit amet, sagittis ac libero. Vestibulum
ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae;
Nam egestas ultricies dui at gravida. Duis tristique, eros id consectetur
pellentesque, nulla arcu ultricies tortor, ut pulvinar sapien lacus in elit.
Vivamus dolor massa, pulvinar at mollis vitae, euismod ut dolor. Vivamus a
magna ante. Vestibulum vitae fringilla leo. Ut gravida magna in quam fringilla
ultricies. Mauris rhoncus enim id sem interdum blandit. Pellentesque luctus leo
sit amet felis viverra ac accumsan purus mollis. Aenean pretium fringilla quam
nec laoreet.

Nulla id mauris mauris. Nam varius bibendum tristique. Integer ante felis,
volutpat sed dignissim vel, interdum molestie nisi. Etiam mollis accumsan elit,
ut gravida eros molestie nec. Nullam quis velit ac purus imperdiet sodales.
Donec semper placerat venenatis. Cras dolor risus, sodales sed scelerisque nec,
sollicitudin pretium felis. Quisque pretium felis id turpis bibendum pulvinar
ornare id nibh. Morbi lobortis leo non mi porttitor vulputate. Vestibulum nec
odio tellus, ut blandit ligula. In pellentesque neque sit amet dui pulvinar sed
laoreet dui vehicula. In hac habitasse platea dictumst. Etiam feugiat dictum
blandit. Praesent lacinia tincidunt elit, quis consectetur tortor molestie
commodo.

Ut sit amet accumsan lorem. Cras quam nunc, malesuada tempor volutpat vitae,
aliquam eu diam. Sed sem nibh, bibendum nec sollicitudin at, interdum et magna.
Cum sociis natoque penatibus et magnis dis parturient montes, nascetur
ridiculus mus. Aliquam vitae sem non elit pharetra vestibulum et condimentum
libero. Nam egestas ultricies hendrerit. Nunc nec fringilla nulla. Aliquam
risus tellus, hendrerit non dapibus a, tincidunt vel ante. Vivamus mollis,
magna et lacinia tincidunt, dui massa porta odio, ac ornare felis massa nec
lorem. Mauris sagittis lacus sed metus mollis ac egestas lectus porttitor.
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cum sociis natoque
penatibus et magnis dis parturient montes, nascetur ridiculus mus. Integer
vitae lacinia libero. Phasellus at neque enim, sit amet dictum mi.

Ut risus nisi, vestibulum vel congue eget, egestas in ipsum. Duis faucibus
tempus sodales. Duis convallis pellentesque arcu rhoncus congue. Nunc ac mauris
eu purus vestibulum congue. Praesent convallis semper augue vel volutpat.
Integer dictum varius placerat. Vestibulum convallis tortor non mi lacinia ac
aliquet dui ultricies. Donec ultrices purus eros. Maecenas venenatis posuere
massa, nec consectetur lacus cursus eget. Donec quam lacus, tempus id placerat
et, posuere sed libero. Proin auctor diam ut arcu viverra ut imperdiet tellus
dapibus.

Morbi ac mauris quis tellus porttitor eleifend. Sed et ante magna, ut sodales
sapien. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices
posuere cubilia Curae; Integer mattis venenatis mi non ullamcorper. Vestibulum
magna enim, aliquam non interdum ut, dignissim vitae ante. Praesent dignissim,
est at pretium posuere, nisl ante varius felis, vitae posuere enim nulla et
nunc. Morbi sagittis suscipit leo, eu accumsan ligula volutpat non. Donec ut
tincidunt magna. Integer ac libero mi. Sed non eros dolor, in tincidunt enim.
Curabitur iaculis erat quis felis iaculis ut volutpat augue malesuada.
Pellentesque eget arcu ligula, ut volutpat purus. Suspendisse dictum lorem quis
sapien lacinia pretium. Lorem ipsum dolor sit amet, consectetur adipiscing
elit.

Proin sagittis egestas massa et tempor. Mauris et eros ante, id porta sem. Duis
ac eros vitae ipsum ultrices malesuada eget a risus. Morbi imperdiet, est a
hendrerit tristique, mi erat molestie lacus, ac tempor risus nulla id erat.
Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac
turpis egestas. Etiam congue, lacus quis ultricies consequat, diam metus
convallis enim, ut volutpat enim urna vitae erat. In quam risus, molestie et
dapibus id, elementum sit amet ligula. Nam faucibus lacus id dolor facilisis
viverra. Nullam vehicula massa ac arcu consectetur vulputate. Praesent nec
augue ac justo dapibus vehicula. Aliquam consectetur hendrerit dolor, et mollis
nisl auctor ut.

Ut sagittis risus at felis fringilla ultricies. Vestibulum non urna nibh, nec
pretium dolor. Nulla imperdiet lobortis eros at pharetra. Vivamus cursus
pellentesque ornare. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
Fusce arcu quam, pulvinar at rutrum vitae, ornare vitae leo. Maecenas vehicula
magna sit amet nulla bibendum condimentum. Curabitur ultrices tempor fringilla.
Vivamus pretium suscipit molestie. Donec arcu diam, ultricies ac pellentesque
eu, venenatis et sapien.

Nam dictum orci augue, vel eleifend leo. Nam at lacus sapien, nec pretium eros.
In egestas, enim sed sagittis feugiat, purus odio tristique lectus, vel
condimentum leo turpis ac odio. Nam iaculis mi quis odio posuere et venenatis
velit ultricies. Nulla facilisi. Proin nec dolor ac quam euismod gravida quis
et eros. Nam interdum condimentum mattis. Cum sociis natoque penatibus et
magnis dis parturient montes, nascetur ridiculus mus. Praesent a nisi eu massa
mollis posuere sed a nunc. Aenean tempus enim a justo rhoncus quis ultrices
nisl commodo.

Aenean imperdiet mauris a ipsum venenatis vel scelerisque lorem rutrum. Donec
ut nunc eros, eget accumsan felis. Nullam ullamcorper porta dictum. Donec
accumsan cursus vestibulum. Aenean in sapien velit. Vivamus nec massa mi. Fusce
felis tortor, bibendum non volutpat a, fringilla quis nisi. Duis varius
bibendum erat, quis fermentum sem accumsan eget. Maecenas massa felis, porta
sed laoreet eu, luctus eu lectus. Cras id nibh vitae erat fringilla rutrum.
Maecenas eget consequat est. Vivamus viverra, felis vel faucibus rhoncus, quam
ipsum elementum libero, quis convallis urna purus ut mauris. Nam quis urna
vitae enim consequat placerat. Vivamus congue augue sit amet lectus luctus
tempor. Cras ut justo convallis est egestas pellentesque ac nec orci.

Vivamus rutrum bibendum ante, at cursus erat pulvinar ornare. Proin imperdiet
scelerisque ante eu vestibulum. Nullam ullamcorper metus nec purus auctor
lobortis. Proin sed lacus et ipsum tempor tempus. Vivamus odio dolor, vulputate
vitae semper sit amet, aliquet egestas orci. Nullam non quam eu quam sagittis
porta. Nunc in velit id erat commodo viverra. Praesent nec est augue, nec
sagittis erat. Cras sed turpis quis enim tempor sagittis. Donec in justo ac
nisl porta condimentum id vestibulum nulla. Nam elementum ultricies nunc a
bibendum.

Aenean tincidunt nisl non augue pellentesque sit amet convallis neque semper.
Cras placerat suscipit massa sed volutpat. Integer vulputate imperdiet enim,
vitae vulputate sapien mattis feugiat. Vivamus pharetra facilisis mauris a
gravida. Nulla non venenatis est. Duis lobortis consectetur sem ac aliquam. In
eget sapien odio. Vivamus pulvinar ultricies magna, quis laoreet dui porta et.
Integer tempus malesuada velit, et consequat odio ultrices sed. Aliquam
malesuada commodo diam vel posuere. Morbi porttitor, elit vitae auctor gravida,
lorem massa bibendum arcu, vel placerat nulla justo at augue.

Aliquam libero quam, mattis blandit congue sit amet, fermentum ac augue.
Aliquam malesuada molestie vulputate. Duis id porta augue. Vestibulum diam
dolor, ultrices sit amet porttitor id, convallis id lectus. Etiam ac augue
tincidunt nisi tempor molestie euismod id nisl. Nam et tortor ac arcu viverra
pulvinar. Fusce pulvinar rhoncus leo, a faucibus enim interdum non. Aliquam
vulputate mattis consectetur. Pellentesque sit amet quam sem. Cras eget arcu eu
elit volutpat volutpat. Integer sed varius enim. Integer sit amet felis orci,
id dignissim sapien. Sed vitae lorem sed libero facilisis fringilla.
Pellentesque congue tristique purus, eleifend semper risus suscipit quis.
Phasellus rutrum quam vitae arcu vulputate porta. Sed tristique arcu nec mi
porttitor lacinia.

Donec congue feugiat diam quis pretium. Vivamus at luctus nunc. Integer
vulputate laoreet mauris quis auctor. Nunc at ultrices libero. Maecenas porta
faucibus purus non vehicula. Sed sit amet metus vitae mi ultrices scelerisque
nec quis risus. Phasellus pellentesque tincidunt massa id ultricies. Aliquam
dictum arcu ac dolor interdum rutrum. Nulla facilisi. Duis nisi est, tincidunt
a sagittis id, sollicitudin at odio. Curabitur sed est eu sapien faucibus
dignissim in quis tortor.

Nunc ac elit tortor, non lobortis massa. Proin posuere ante ut metus vehicula
suscipit. Proin mattis mauris ac lectus consequat rutrum. Nam arcu lectus,
commodo non pretium a, pharetra semper dolor. Fusce eleifend hendrerit
adipiscing. Nunc et eleifend erat. Suspendisse tempus nisl ut arcu blandit ut
adipiscing nisi tristique. Suspendisse molestie facilisis risus sed fermentum.
Praesent tempor convallis ultricies. Integer et elit velit, at consectetur
risus.

Vestibulum mollis adipiscing sodales. Vestibulum ante ipsum primis in faucibus
orci luctus et ultrices posuere cubilia Curae; Mauris dictum molestie porta.
Nam convallis nisl quis lacus vulputate in convallis risus sagittis. Vivamus
accumsan faucibus cursus. Ut ultricies imperdiet ligula scelerisque blandit. In
ornare egestas purus, at convallis velit egestas laoreet. Class aptent taciti
sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Nulla
quis imperdiet est. Nunc tempus magna quis lacus feugiat et posuere lacus
vehicula. Cras lacinia aliquam est at vehicula. Aenean congue elit in ante
dignissim vitae fermentum lectus aliquam. Mauris at odio magna, at interdum
dui. Cras fringilla mi velit, nec varius neque.

Fusce et volutpat lacus. Suspendisse id turpis et urna varius convallis in eu
purus. Nulla facilisi. Etiam mauris nisl, ultrices ac porttitor sit amet,
facilisis ut neque. Nullam ut velit quis velit tincidunt rhoncus. Praesent
tristique porttitor euismod. Nulla non felis ante, feugiat commodo turpis. In
nec venenatis mi. Duis tempus tempor purus, vitae consectetur mi ornare eu.
Proin sed consequat erat. Quisque nec sem dui. Nam semper, ligula facilisis
pretium interdum, diam lectus sollicitudin lorem, in elementum nisi lorem
scelerisque justo. Nullam ac fringilla nunc. Maecenas malesuada ligula in massa
sollicitudin sit amet auctor ipsum malesuada. Vestibulum ut augue in magna
lobortis varius eget in ipsum. In hac habitasse platea dictumst.

Cras vel sagittis mi. Aenean urna sapien, ultrices et tristique et, aliquam vel
libero. Nullam in consequat ante. Suspendisse libero augue, pulvinar a
dignissim vitae, fringilla malesuada dui. Phasellus augue ante, pulvinar eget
tincidunt vel, venenatis sed arcu. Pellentesque ac purus orci, vel molestie
turpis. Nulla consectetur sollicitudin dolor, sed ornare arcu accumsan
fermentum. Fusce vestibulum nisi at leo interdum eu sollicitudin lacus dictum.
Fusce malesuada consequat ipsum ut convallis. Maecenas in eros sit amet elit
consectetur fringilla nec a nibh. Ut et velit vel ligula pharetra elementum.
Nullam aliquam, tellus vel cursus lacinia, dui libero dictum turpis, nec
lacinia dolor nunc vel diam. Pellentesque convallis dui quis lacus ornare at
rutrum lorem pellentesque. Suspendisse potenti. Cum sociis natoque penatibus et
magnis dis parturient montes, nascetur ridiculus mus.

Nunc ac nibh sed mauris ornare cursus. Praesent enim mauris, tincidunt vitae
convallis ac, ultricies imperdiet sapien. Duis sodales ligula eget lorem
suscipit sed consectetur metus pretium. Nam in magna augue, quis volutpat
mauris. Quisque pretium lobortis orci quis laoreet. Nam ut nisi diam. Sed
ultrices ultrices dapibus. Integer feugiat mauris id orci pulvinar eu tempus
nibh viverra. Etiam venenatis bibendum massa a consequat. Fusce interdum velit
ac mauris rhoncus non cursus neque consectetur. Vestibulum dictum eros ac metus
fringilla venenatis. Phasellus auctor dui non nulla molestie id malesuada
mauris euismod. Aenean id tortor ac justo eleifend mollis non vel arcu. Duis ac
lorem tortor. Donec volutpat purus sed nunc luctus interdum hendrerit nulla
ullamcorper. Sed consectetur interdum aliquet. Proin ullamcorper risus ut ante
lacinia sagittis. Nunc varius eleifend purus, ac pellentesque urna viverra id.
Praesent euismod, sapien accumsan gravida dictum, massa massa euismod sapien,
ut auctor tellus arcu sed diam.

Vivamus tincidunt dolor non lorem pellentesque at tempus elit adipiscing.
Vestibulum tempor aliquam consectetur. Mauris nec dictum nisl. Donec
scelerisque ornare condimentum. Phasellus laoreet justo nec nibh convallis
convallis. Duis id orci sapien, eget pulvinar justo. Aenean id arcu felis, eu
iaculis nibh. Aenean eleifend pretium rutrum. Aliquam molestie sem quis tellus
aliquam eleifend. Mauris et purus orci. Nunc et accumsan tortor. Phasellus
semper eleifend nisi, a faucibus risus vehicula id. Lorem ipsum dolor sit amet,
consectetur adipiscing elit. Maecenas in felis et est lacinia eleifend vel sed
ipsum. Aliquam commodo molestie lorem id hendrerit. Nam sed tellus urna, sed
dignissim eros.

"""


A_LONG_STRING = """A long string.

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer sit amet
mauris mauris, sit amet venenatis nisl. Vivamus a est porta enim sollicitudin
mollis. Proin fringilla massa vel ante gravida luctus. Nunc quis nunc id quam
hendrerit posuere. Cum sociis natoque penatibus et magnis dis parturient
montes, nascetur ridiculus mus. Aliquam porttitor interdum sollicitudin. Mauris
malesuada tellus tellus. Mauris condimentum nunc et sapien pellentesque
gravida. Suspendisse sed ipsum orci. Duis ut lacus dui. Integer ac gravida sem.
Vivamus fermentum porttitor velit ac blandit. Maecenas pulvinar ullamcorper
enim, vitae aliquet tortor scelerisque et. Vestibulum ante massa, sodales et
bibendum dignissim, consectetur vitae metus. Quisque vel dui erat, vel commodo
metus. Aliquam arcu dolor, viverra sit amet porttitor a, faucibus eu augue.

Sed ornare, enim eget ultricies suscipit, nunc dui lacinia enim, vitae tempus
nunc libero vitae ligula. Nam et commodo ligula. Pellentesque tincidunt lorem
at elit aliquam at fringilla libero tempor. Donec molestie consectetur nibh, ac
varius ante dictum id. Suspendisse lectus nibh, molestie vel dapibus eget,
egestas ut eros. Mauris vel mauris turpis, vitae bibendum nunc. Vestibulum
nulla enim, vestibulum vitae tincidunt et, gravida eu metus. Nulla sagittis,
odio a placerat laoreet, arcu lectus vestibulum nunc, in hendrerit tortor quam
sit amet turpis. In et purus vel dui pellentesque tincidunt. Donec dictum nibh
sed quam luctus sit amet luctus justo dapibus. Integer nulla elit, lacinia
aliquet euismod sed, tempus vitae lectus. Fusce non sapien dolor. Suspendisse
ut est ut dui tempor ultricies id ut elit. Aenean adipiscing sollicitudin enim,
nec porttitor est porttitor eget. Proin lobortis ante ut diam sodales volutpat.
Donec urna diam, porttitor nec laoreet ut, rhoncus non diam.

Ut sed mi vitae turpis semper semper. Integer sit amet lorem sapien. Aliquam
risus diam, vulputate id sagittis et, molestie ut lectus. Aliquam erat
volutpat. Morbi aliquet venenatis metus in posuere. Cras vitae purus nunc, ut
vestibulum ipsum. Nullam vehicula dui in urna iaculis lobortis. Ut a est non
est tincidunt iaculis. Vivamus rutrum velit non nunc malesuada sed bibendum mi
iaculis. Sed id lacus in sem tempor vestibulum. Cras bibendum accumsan
suscipit. Phasellus congue nisl consectetur turpis rhoncus aliquet posuere
libero fringilla. Sed eros tellus, hendrerit nec imperdiet vitae, blandit ac
dolor. Nulla facilisi. Morbi ullamcorper libero odio, at cursus tortor. Cras
ultricies tellus eget justo cursus cursus. Donec at mi massa, auctor suscipit
sem.

Proin dolor purus, semper sed ultrices ut, iaculis at tortor. Donec risus enim,
interdum et convallis nec, aliquam eget velit. Curabitur eget lectus dolor.
Integer id turpis eu nulla euismod tincidunt. Fusce elit nibh, dapibus sit amet
tempus ac, convallis eu libero. Donec dui justo, molestie sed euismod porta,
ultricies id orci. Praesent a tellus et risus faucibus porttitor pellentesque
in purus. Fusce blandit risus ac tortor viverra vitae molestie odio convallis.
Donec rhoncus volutpat mauris, sit amet mattis libero dapibus id. Ut rhoncus
venenatis nisi ac dictum. In non nulla eget massa convallis facilisis. Praesent
nec odio id odio semper lobortis non eu erat. Proin quis gravida magna. Sed
rhoncus lectus auctor arcu posuere a auctor dui pellentesque.

Sed enim nulla, luctus quis sagittis sed, vestibulum eget metus. Mauris ornare
pretium fringilla. Proin ligula eros, fermentum in placerat sit amet, placerat
vel mauris. Nulla magna enim, luctus eget euismod ac, lacinia vel lorem. Duis
mi leo, porttitor vitae dictum ac, ultrices iaculis metus. Quisque libero mi,
aliquet quis vestibulum eget, porttitor non justo. Praesent ac metus felis.
Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac
turpis egestas. Donec vel enim sit amet ante imperdiet commodo sed vel nisi.
Praesent semper viverra nulla vehicula sollicitudin. Fusce lacinia aliquet
ullamcorper. Donec vitae diam est. Integer volutpat hendrerit turpis ut
bibendum. Integer et dui augue.

Nunc ut nisl in felis feugiat semper nec sit amet purus. Proin convallis
ultrices nisl ut vehicula. Pellentesque neque mi, elementum vel placerat nec,
laoreet ac nulla. Pellentesque aliquam dui a metus iaculis posuere. Curabitur
dapibus faucibus metus. Donec quis diam dui. Proin at mi nec augue cursus
pulvinar eu vel metus. Curabitur eget turpis ac risus dignissim luctus sed id
ligula. Etiam lectus neque, varius ut euismod nec, euismod quis nulla. Ut
feugiat, quam id tempor luctus, metus eros lacinia diam, nec dapibus tellus dui
quis diam. Nam interdum, orci id fringilla mattis, ipsum eros pellentesque
turpis, hendrerit dignissim justo dui interdum ante. Curabitur aliquam nisi ut
dui lacinia tempor. Nulla lobortis tellus non sapien dignissim ut dapibus dui
aliquet. Nam scelerisque, urna a aliquam malesuada, mi tortor scelerisque
libero, quis pellentesque erat eros ut justo.

Phasellus nulla purus, suscipit vel gravida euismod, malesuada et odio.
Vestibulum non libero eget lacus venenatis auctor quis a est. Nunc id leo est.
Curabitur pulvinar viverra sapien at viverra. Cras pretium justo et lorem
lobortis id tempor nisi accumsan. Cras egestas tortor in risus hendrerit eu
varius purus suscipit. Nullam mauris eros, mattis at tempor vitae, mollis vitae
velit. Etiam at adipiscing lectus. Quisque molestie, metus id posuere pharetra,
lorem enim vehicula mauris, ut ultricies purus justo a lacus. Vivamus blandit
euismod adipiscing. Nam eu ligula at elit ultricies tempus. Nunc ac sodales
neque. Ut dui diam, porttitor a pulvinar vel, sodales sit amet turpis. Donec
vitae eros at neque luctus scelerisque. In consequat elementum iaculis. Donec
ullamcorper dolor eu quam volutpat rhoncus. Lorem ipsum dolor sit amet,
consectetur adipiscing elit. Cras laoreet ante eget dolor sagittis imperdiet.
Proin magna urna, porta id blandit nec, commodo eget lorem.

Etiam imperdiet, orci sit amet rutrum consectetur, orci augue tempus lacus, id
venenatis sapien nisl a est. Sed accumsan massa sed libero consectetur
scelerisque. Class aptent taciti sociosqu ad litora torquent per conubia
nostra, per inceptos himenaeos. Sed nunc risus, lobortis id egestas nec,
suscipit id magna. Morbi at iaculis mauris. Proin felis sem, tempus non
pellentesque congue, vehicula sit amet eros. Maecenas porttitor erat ac dolor
pharetra iaculis. Cras tincidunt, nulla eget malesuada egestas, sem diam
consequat quam, sed feugiat nulla orci at mauris. Quisque non arcu diam, ac
lacinia felis. Nunc iaculis mollis egestas. Etiam imperdiet dolor consectetur
eros feugiat fringilla sed in lacus. Nunc nec tincidunt dolor. Etiam sagittis
tortor condimentum nunc fermentum vestibulum. Vivamus lobortis, magna sit amet
scelerisque lobortis, sem eros molestie leo, eget aliquet ligula est in lectus.
Duis placerat porta pulvinar. Sed sed adipiscing ante. Vestibulum ante ipsum
primis in faucibus orci luctus et ultrices posuere cubilia Curae; Nam accumsan
iaculis augue, sed varius dui sagittis id. Etiam sit amet eleifend augue.

Ut sit amet nibh sit amet justo tempor condimentum. Ut faucibus sagittis
volutpat. Duis vestibulum feugiat sollicitudin. Aenean cursus luctus urna at
consectetur. Nullam tincidunt, eros a iaculis sodales, tellus est imperdiet
arcu, sit amet tincidunt orci felis et tortor. Mauris rutrum venenatis nunc ut
rutrum. Phasellus nec erat magna, in tincidunt orci. Sed sit amet suscipit
tellus. Mauris ut nisi turpis. Suspendisse augue turpis, condimentum ac
bibendum in, vestibulum nec eros. Curabitur dapibus pulvinar vehicula. Fusce
consequat, erat in malesuada hendrerit, tellus urna pharetra lacus, sed euismod
nisi urna sed nisi. Etiam fermentum accumsan nunc, sed bibendum dui iaculis id.
Etiam blandit fermentum ligula nec viverra. Vivamus venenatis arcu in nulla
euismod euismod. Donec sit amet augue nec metus varius fringilla. Vivamus
pulvinar elit ac mi rhoncus in luctus diam egestas. Curabitur a felis eget arcu
pretium tempus eu sed mauris. Vestibulum ante ipsum primis in faucibus orci
luctus et ultrices posuere cubilia Curae;

Mauris malesuada, nibh ac venenatis hendrerit, ligula dui condimentum tellus,
sit amet pretium diam tortor vel risus. Suspendisse suscipit consequat eros id
dignissim. Cras interdum lorem ac massa euismod non porta enim pretium. Aliquam
ultrices nibh vitae ligula consectetur vel sollicitudin lacus volutpat.
Phasellus vulputate iaculis sem nec laoreet. Nam leo sem, tempor eu condimentum
id, imperdiet sed dolor. Donec pharetra velit non libero euismod tempor.
Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere
cubilia Curae; Sed fermentum, libero a posuere posuere, enim elit imperdiet
enim, a sollicitudin est felis non libero. Sed vel dolor ut arcu dapibus
iaculis nec a mauris. Morbi ullamcorper ultrices venenatis. Fusce luctus ante
sit amet lacus venenatis ut rutrum elit lobortis. Nulla fermentum tortor ac
sapien fringilla quis iaculis quam egestas.

Aliquam et tortor est, at elementum mauris. Morbi posuere erat nec leo
vulputate in pellentesque tortor condimentum. Vestibulum at orci augue. Aenean
pellentesque sapien id felis consequat varius. Suspendisse bibendum enim sit
amet mi imperdiet vel suscipit nisi tristique. Curabitur velit massa,
consectetur ac mattis vel, accumsan at nunc. Donec porta, nibh nec consequat
convallis, urna neque auctor erat, eu convallis lorem leo convallis turpis.
Morbi non mauris non metus ornare vulputate. Sed aliquet, dolor ut egestas
fermentum, metus purus mollis elit, nec commodo odio quam quis nisl. Aliquam
erat volutpat. Suspendisse sed faucibus urna. Integer suscipit rutrum
condimentum. Praesent dignissim libero eget metus luctus consectetur.

Vestibulum ac erat felis, vitae iaculis erat. Duis interdum lacinia arcu, non
lacinia urna luctus in. Curabitur feugiat sapien sapien, in vestibulum diam.
Phasellus lobortis massa ut metus pretium dignissim. Fusce quis sem odio.
Integer pellentesque sodales augue id tincidunt. Pellentesque habitant morbi
tristique senectus et netus et malesuada fames ac turpis egestas. Vestibulum
lorem odio, semper vel scelerisque sit amet, sagittis ac libero. Vestibulum
ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae;
Nam egestas ultricies dui at gravida. Duis tristique, eros id consectetur
pellentesque, nulla arcu ultricies tortor, ut pulvinar sapien lacus in elit.
Vivamus dolor massa, pulvinar at mollis vitae, euismod ut dolor. Vivamus a
magna ante. Vestibulum vitae fringilla leo. Ut gravida magna in quam fringilla
ultricies. Mauris rhoncus enim id sem interdum blandit. Pellentesque luctus leo
sit amet felis viverra ac accumsan purus mollis. Aenean pretium fringilla quam
nec laoreet.

Nulla id mauris mauris. Nam varius bibendum tristique. Integer ante felis,
volutpat sed dignissim vel, interdum molestie nisi. Etiam mollis accumsan elit,
ut gravida eros molestie nec. Nullam quis velit ac purus imperdiet sodales.
Donec semper placerat venenatis. Cras dolor risus, sodales sed scelerisque nec,
sollicitudin pretium felis. Quisque pretium felis id turpis bibendum pulvinar
ornare id nibh. Morbi lobortis leo non mi porttitor vulputate. Vestibulum nec
odio tellus, ut blandit ligula. In pellentesque neque sit amet dui pulvinar sed
laoreet dui vehicula. In hac habitasse platea dictumst. Etiam feugiat dictum
blandit. Praesent lacinia tincidunt elit, quis consectetur tortor molestie
commodo.

Ut sit amet accumsan lorem. Cras quam nunc, malesuada tempor volutpat vitae,
aliquam eu diam. Sed sem nibh, bibendum nec sollicitudin at, interdum et magna.
Cum sociis natoque penatibus et magnis dis parturient montes, nascetur
ridiculus mus. Aliquam vitae sem non elit pharetra vestibulum et condimentum
libero. Nam egestas ultricies hendrerit. Nunc nec fringilla nulla. Aliquam
risus tellus, hendrerit non dapibus a, tincidunt vel ante. Vivamus mollis,
magna et lacinia tincidunt, dui massa porta odio, ac ornare felis massa nec
lorem. Mauris sagittis lacus sed metus mollis ac egestas lectus porttitor.
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cum sociis natoque
penatibus et magnis dis parturient montes, nascetur ridiculus mus. Integer
vitae lacinia libero. Phasellus at neque enim, sit amet dictum mi.

Ut risus nisi, vestibulum vel congue eget, egestas in ipsum. Duis faucibus
tempus sodales. Duis convallis pellentesque arcu rhoncus congue. Nunc ac mauris
eu purus vestibulum congue. Praesent convallis semper augue vel volutpat.
Integer dictum varius placerat. Vestibulum convallis tortor non mi lacinia ac
aliquet dui ultricies. Donec ultrices purus eros. Maecenas venenatis posuere
massa, nec consectetur lacus cursus eget. Donec quam lacus, tempus id placerat
et, posuere sed libero. Proin auctor diam ut arcu viverra ut imperdiet tellus
dapibus.

Morbi ac mauris quis tellus porttitor eleifend. Sed et ante magna, ut sodales
sapien. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices
posuere cubilia Curae; Integer mattis venenatis mi non ullamcorper. Vestibulum
magna enim, aliquam non interdum ut, dignissim vitae ante. Praesent dignissim,
est at pretium posuere, nisl ante varius felis, vitae posuere enim nulla et
nunc. Morbi sagittis suscipit leo, eu accumsan ligula volutpat non. Donec ut
tincidunt magna. Integer ac libero mi. Sed non eros dolor, in tincidunt enim.
Curabitur iaculis erat quis felis iaculis ut volutpat augue malesuada.
Pellentesque eget arcu ligula, ut volutpat purus. Suspendisse dictum lorem quis
sapien lacinia pretium. Lorem ipsum dolor sit amet, consectetur adipiscing
elit.

Proin sagittis egestas massa et tempor. Mauris et eros ante, id porta sem. Duis
ac eros vitae ipsum ultrices malesuada eget a risus. Morbi imperdiet, est a
hendrerit tristique, mi erat molestie lacus, ac tempor risus nulla id erat.
Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac
turpis egestas. Etiam congue, lacus quis ultricies consequat, diam metus
convallis enim, ut volutpat enim urna vitae erat. In quam risus, molestie et
dapibus id, elementum sit amet ligula. Nam faucibus lacus id dolor facilisis
viverra. Nullam vehicula massa ac arcu consectetur vulputate. Praesent nec
augue ac justo dapibus vehicula. Aliquam consectetur hendrerit dolor, et mollis
nisl auctor ut.

Ut sagittis risus at felis fringilla ultricies. Vestibulum non urna nibh, nec
pretium dolor. Nulla imperdiet lobortis eros at pharetra. Vivamus cursus
pellentesque ornare. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
Fusce arcu quam, pulvinar at rutrum vitae, ornare vitae leo. Maecenas vehicula
magna sit amet nulla bibendum condimentum. Curabitur ultrices tempor fringilla.
Vivamus pretium suscipit molestie. Donec arcu diam, ultricies ac pellentesque
eu, venenatis et sapien.

Nam dictum orci augue, vel eleifend leo. Nam at lacus sapien, nec pretium eros.
In egestas, enim sed sagittis feugiat, purus odio tristique lectus, vel
condimentum leo turpis ac odio. Nam iaculis mi quis odio posuere et venenatis
velit ultricies. Nulla facilisi. Proin nec dolor ac quam euismod gravida quis
et eros. Nam interdum condimentum mattis. Cum sociis natoque penatibus et
magnis dis parturient montes, nascetur ridiculus mus. Praesent a nisi eu massa
mollis posuere sed a nunc. Aenean tempus enim a justo rhoncus quis ultrices
nisl commodo.

Aenean imperdiet mauris a ipsum venenatis vel scelerisque lorem rutrum. Donec
ut nunc eros, eget accumsan felis. Nullam ullamcorper porta dictum. Donec
accumsan cursus vestibulum. Aenean in sapien velit. Vivamus nec massa mi. Fusce
felis tortor, bibendum non volutpat a, fringilla quis nisi. Duis varius
bibendum erat, quis fermentum sem accumsan eget. Maecenas massa felis, porta
sed laoreet eu, luctus eu lectus. Cras id nibh vitae erat fringilla rutrum.
Maecenas eget consequat est. Vivamus viverra, felis vel faucibus rhoncus, quam
ipsum elementum libero, quis convallis urna purus ut mauris. Nam quis urna
vitae enim consequat placerat. Vivamus congue augue sit amet lectus luctus
tempor. Cras ut justo convallis est egestas pellentesque ac nec orci.

Vivamus rutrum bibendum ante, at cursus erat pulvinar ornare. Proin imperdiet
scelerisque ante eu vestibulum. Nullam ullamcorper metus nec purus auctor
lobortis. Proin sed lacus et ipsum tempor tempus. Vivamus odio dolor, vulputate
vitae semper sit amet, aliquet egestas orci. Nullam non quam eu quam sagittis
porta. Nunc in velit id erat commodo viverra. Praesent nec est augue, nec
sagittis erat. Cras sed turpis quis enim tempor sagittis. Donec in justo ac
nisl porta condimentum id vestibulum nulla. Nam elementum ultricies nunc a
bibendum.

Aenean tincidunt nisl non augue pellentesque sit amet convallis neque semper.
Cras placerat suscipit massa sed volutpat. Integer vulputate imperdiet enim,
vitae vulputate sapien mattis feugiat. Vivamus pharetra facilisis mauris a
gravida. Nulla non venenatis est. Duis lobortis consectetur sem ac aliquam. In
eget sapien odio. Vivamus pulvinar ultricies magna, quis laoreet dui porta et.
Integer tempus malesuada velit, et consequat odio ultrices sed. Aliquam
malesuada commodo diam vel posuere. Morbi porttitor, elit vitae auctor gravida,
lorem massa bibendum arcu, vel placerat nulla justo at augue.

Aliquam libero quam, mattis blandit congue sit amet, fermentum ac augue.
Aliquam malesuada molestie vulputate. Duis id porta augue. Vestibulum diam
dolor, ultrices sit amet porttitor id, convallis id lectus. Etiam ac augue
tincidunt nisi tempor molestie euismod id nisl. Nam et tortor ac arcu viverra
pulvinar. Fusce pulvinar rhoncus leo, a faucibus enim interdum non. Aliquam
vulputate mattis consectetur. Pellentesque sit amet quam sem. Cras eget arcu eu
elit volutpat volutpat. Integer sed varius enim. Integer sit amet felis orci,
id dignissim sapien. Sed vitae lorem sed libero facilisis fringilla.
Pellentesque congue tristique purus, eleifend semper risus suscipit quis.
Phasellus rutrum quam vitae arcu vulputate porta. Sed tristique arcu nec mi
porttitor lacinia.

Donec congue feugiat diam quis pretium. Vivamus at luctus nunc. Integer
vulputate laoreet mauris quis auctor. Nunc at ultrices libero. Maecenas porta
faucibus purus non vehicula. Sed sit amet metus vitae mi ultrices scelerisque
nec quis risus. Phasellus pellentesque tincidunt massa id ultricies. Aliquam
dictum arcu ac dolor interdum rutrum. Nulla facilisi. Duis nisi est, tincidunt
a sagittis id, sollicitudin at odio. Curabitur sed est eu sapien faucibus
dignissim in quis tortor.

Nunc ac elit tortor, non lobortis massa. Proin posuere ante ut metus vehicula
suscipit. Proin mattis mauris ac lectus consequat rutrum. Nam arcu lectus,
commodo non pretium a, pharetra semper dolor. Fusce eleifend hendrerit
adipiscing. Nunc et eleifend erat. Suspendisse tempus nisl ut arcu blandit ut
adipiscing nisi tristique. Suspendisse molestie facilisis risus sed fermentum.
Praesent tempor convallis ultricies. Integer et elit velit, at consectetur
risus.

Vestibulum mollis adipiscing sodales. Vestibulum ante ipsum primis in faucibus
orci luctus et ultrices posuere cubilia Curae; Mauris dictum molestie porta.
Nam convallis nisl quis lacus vulputate in convallis risus sagittis. Vivamus
accumsan faucibus cursus. Ut ultricies imperdiet ligula scelerisque blandit. In
ornare egestas purus, at convallis velit egestas laoreet. Class aptent taciti
sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Nulla
quis imperdiet est. Nunc tempus magna quis lacus feugiat et posuere lacus
vehicula. Cras lacinia aliquam est at vehicula. Aenean congue elit in ante
dignissim vitae fermentum lectus aliquam. Mauris at odio magna, at interdum
dui. Cras fringilla mi velit, nec varius neque.

Fusce et volutpat lacus. Suspendisse id turpis et urna varius convallis in eu
purus. Nulla facilisi. Etiam mauris nisl, ultrices ac porttitor sit amet,
facilisis ut neque. Nullam ut velit quis velit tincidunt rhoncus. Praesent
tristique porttitor euismod. Nulla non felis ante, feugiat commodo turpis. In
nec venenatis mi. Duis tempus tempor purus, vitae consectetur mi ornare eu.
Proin sed consequat erat. Quisque nec sem dui. Nam semper, ligula facilisis
pretium interdum, diam lectus sollicitudin lorem, in elementum nisi lorem
scelerisque justo. Nullam ac fringilla nunc. Maecenas malesuada ligula in massa
sollicitudin sit amet auctor ipsum malesuada. Vestibulum ut augue in magna
lobortis varius eget in ipsum. In hac habitasse platea dictumst.

Cras vel sagittis mi. Aenean urna sapien, ultrices et tristique et, aliquam vel
libero. Nullam in consequat ante. Suspendisse libero augue, pulvinar a
dignissim vitae, fringilla malesuada dui. Phasellus augue ante, pulvinar eget
tincidunt vel, venenatis sed arcu. Pellentesque ac purus orci, vel molestie
turpis. Nulla consectetur sollicitudin dolor, sed ornare arcu accumsan
fermentum. Fusce vestibulum nisi at leo interdum eu sollicitudin lacus dictum.
Fusce malesuada consequat ipsum ut convallis. Maecenas in eros sit amet elit
consectetur fringilla nec a nibh. Ut et velit vel ligula pharetra elementum.
Nullam aliquam, tellus vel cursus lacinia, dui libero dictum turpis, nec
lacinia dolor nunc vel diam. Pellentesque convallis dui quis lacus ornare at
rutrum lorem pellentesque. Suspendisse potenti. Cum sociis natoque penatibus et
magnis dis parturient montes, nascetur ridiculus mus.

Nunc ac nibh sed mauris ornare cursus. Praesent enim mauris, tincidunt vitae
convallis ac, ultricies imperdiet sapien. Duis sodales ligula eget lorem
suscipit sed consectetur metus pretium. Nam in magna augue, quis volutpat
mauris. Quisque pretium lobortis orci quis laoreet. Nam ut nisi diam. Sed
ultrices ultrices dapibus. Integer feugiat mauris id orci pulvinar eu tempus
nibh viverra. Etiam venenatis bibendum massa a consequat. Fusce interdum velit
ac mauris rhoncus non cursus neque consectetur. Vestibulum dictum eros ac metus
fringilla venenatis. Phasellus auctor dui non nulla molestie id malesuada
mauris euismod. Aenean id tortor ac justo eleifend mollis non vel arcu. Duis ac
lorem tortor. Donec volutpat purus sed nunc luctus interdum hendrerit nulla
ullamcorper. Sed consectetur interdum aliquet. Proin ullamcorper risus ut ante
lacinia sagittis. Nunc varius eleifend purus, ac pellentesque urna viverra id.
Praesent euismod, sapien accumsan gravida dictum, massa massa euismod sapien,
ut auctor tellus arcu sed diam.

Vivamus tincidunt dolor non lorem pellentesque at tempus elit adipiscing.
Vestibulum tempor aliquam consectetur. Mauris nec dictum nisl. Donec
scelerisque ornare condimentum. Phasellus laoreet justo nec nibh convallis
convallis. Duis id orci sapien, eget pulvinar justo. Aenean id arcu felis, eu
iaculis nibh. Aenean eleifend pretium rutrum. Aliquam molestie sem quis tellus
aliquam eleifend. Mauris et purus orci. Nunc et accumsan tortor. Phasellus
semper eleifend nisi, a faucibus risus vehicula id. Lorem ipsum dolor sit amet,
consectetur adipiscing elit. Maecenas in felis et est lacinia eleifend vel sed
ipsum. Aliquam commodo molestie lorem id hendrerit. Nam sed tellus urna, sed
dignissim eros.

"""

def a_function():
    """A long function docstring.

    Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer sit amet
    mauris mauris, sit amet venenatis nisl. Vivamus a est porta enim
    sollicitudin mollis. Proin fringilla massa vel ante gravida luctus. Nunc
    quis nunc id quam hendrerit posuere. Cum sociis natoque penatibus et magnis
    dis parturient montes, nascetur ridiculus mus. Aliquam porttitor interdum
    sollicitudin. Mauris malesuada tellus tellus. Mauris condimentum nunc et
    sapien pellentesque gravida. Suspendisse sed ipsum orci. Duis ut lacus dui.
    Integer ac gravida sem. Vivamus fermentum porttitor velit ac blandit.
    Maecenas pulvinar ullamcorper enim, vitae aliquet tortor scelerisque et.
    Vestibulum ante massa, sodales et bibendum dignissim, consectetur vitae
    metus. Quisque vel dui erat, vel commodo metus. Aliquam arcu dolor, viverra
    sit amet porttitor a, faucibus eu augue.

    Sed ornare, enim eget ultricies suscipit, nunc dui lacinia enim, vitae
    tempus nunc libero vitae ligula. Nam et commodo ligula. Pellentesque
    tincidunt lorem at elit aliquam at fringilla libero tempor. Donec molestie
    consectetur nibh, ac varius ante dictum id. Suspendisse lectus nibh,
    molestie vel dapibus eget, egestas ut eros. Mauris vel mauris turpis, vitae
    bibendum nunc. Vestibulum nulla enim, vestibulum vitae tincidunt et,
    gravida eu metus. Nulla sagittis, odio a placerat laoreet, arcu lectus
    vestibulum nunc, in hendrerit tortor quam sit amet turpis. In et purus vel
    dui pellentesque tincidunt. Donec dictum nibh sed quam luctus sit amet
    luctus justo dapibus. Integer nulla elit, lacinia aliquet euismod sed,
    tempus vitae lectus. Fusce non sapien dolor. Suspendisse ut est ut dui
    tempor ultricies id ut elit. Aenean adipiscing sollicitudin enim, nec
    porttitor est porttitor eget. Proin lobortis ante ut diam sodales volutpat.
    Donec urna diam, porttitor nec laoreet ut, rhoncus non diam.

    Ut sed mi vitae turpis semper semper. Integer sit amet lorem sapien.
    Aliquam risus diam, vulputate id sagittis et, molestie ut lectus. Aliquam
    erat volutpat. Morbi aliquet venenatis metus in posuere. Cras vitae purus
    nunc, ut vestibulum ipsum. Nullam vehicula dui in urna iaculis lobortis. Ut
    a est non est tincidunt iaculis. Vivamus rutrum velit non nunc malesuada
    sed bibendum mi iaculis. Sed id lacus in sem tempor vestibulum. Cras
    bibendum accumsan suscipit. Phasellus congue nisl consectetur turpis
    rhoncus aliquet posuere libero fringilla. Sed eros tellus, hendrerit nec
    imperdiet vitae, blandit ac dolor. Nulla facilisi. Morbi ullamcorper libero
    odio, at cursus tortor. Cras ultricies tellus eget justo cursus cursus.
    Donec at mi massa, auctor suscipit sem.

    Proin dolor purus, semper sed ultrices ut, iaculis at tortor. Donec risus
    enim, interdum et convallis nec, aliquam eget velit. Curabitur eget lectus
    dolor. Integer id turpis eu nulla euismod tincidunt. Fusce elit nibh,
    dapibus sit amet tempus ac, convallis eu libero. Donec dui justo, molestie
    sed euismod porta, ultricies id orci. Praesent a tellus et risus faucibus
    porttitor pellentesque in purus. Fusce blandit risus ac tortor viverra
    vitae molestie odio convallis. Donec rhoncus volutpat mauris, sit amet
    mattis libero dapibus id. Ut rhoncus venenatis nisi ac dictum. In non nulla
    eget massa convallis facilisis. Praesent nec odio id odio semper lobortis
    non eu erat. Proin quis gravida magna. Sed rhoncus lectus auctor arcu
    posuere a auctor dui pellentesque.

    Sed enim nulla, luctus quis sagittis sed, vestibulum eget metus. Mauris
    ornare pretium fringilla. Proin ligula eros, fermentum in placerat sit
    amet, placerat vel mauris. Nulla magna enim, luctus eget euismod ac,
    lacinia vel lorem. Duis mi leo, porttitor vitae dictum ac, ultrices iaculis
    metus. Quisque libero mi, aliquet quis vestibulum eget, porttitor non
    justo. Praesent ac metus felis. Pellentesque habitant morbi tristique
    senectus et netus et malesuada fames ac turpis egestas. Donec vel enim sit
    amet ante imperdiet commodo sed vel nisi. Praesent semper viverra nulla
    vehicula sollicitudin. Fusce lacinia aliquet ullamcorper. Donec vitae diam
    est. Integer volutpat hendrerit turpis ut bibendum. Integer et dui augue.

    Nunc ut nisl in felis feugiat semper nec sit amet purus. Proin convallis
    ultrices nisl ut vehicula. Pellentesque neque mi, elementum vel placerat
    nec, laoreet ac nulla. Pellentesque aliquam dui a metus iaculis posuere.
    Curabitur dapibus faucibus metus. Donec quis diam dui. Proin at mi nec
    augue cursus pulvinar eu vel metus. Curabitur eget turpis ac risus
    dignissim luctus sed id ligula. Etiam lectus neque, varius ut euismod nec,
    euismod quis nulla. Ut feugiat, quam id tempor luctus, metus eros lacinia
    diam, nec dapibus tellus dui quis diam. Nam interdum, orci id fringilla
    mattis, ipsum eros pellentesque turpis, hendrerit dignissim justo dui
    interdum ante. Curabitur aliquam nisi ut dui lacinia tempor. Nulla lobortis
    tellus non sapien dignissim ut dapibus dui aliquet. Nam scelerisque, urna a
    aliquam malesuada, mi tortor scelerisque libero, quis pellentesque erat
    eros ut justo.

    Phasellus nulla purus, suscipit vel gravida euismod, malesuada et odio.
    Vestibulum non libero eget lacus venenatis auctor quis a est. Nunc id leo
    est. Curabitur pulvinar viverra sapien at viverra. Cras pretium justo et
    lorem lobortis id tempor nisi accumsan. Cras egestas tortor in risus
    hendrerit eu varius purus suscipit. Nullam mauris eros, mattis at tempor
    vitae, mollis vitae velit. Etiam at adipiscing lectus. Quisque molestie,
    metus id posuere pharetra, lorem enim vehicula mauris, ut ultricies purus
    justo a lacus. Vivamus blandit euismod adipiscing. Nam eu ligula at elit
    ultricies tempus. Nunc ac sodales neque. Ut dui diam, porttitor a pulvinar
    vel, sodales sit amet turpis. Donec vitae eros at neque luctus scelerisque.
    In consequat elementum iaculis. Donec ullamcorper dolor eu quam volutpat
    rhoncus. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras
    laoreet ante eget dolor sagittis imperdiet. Proin magna urna, porta id
    blandit nec, commodo eget lorem.

    Etiam imperdiet, orci sit amet rutrum consectetur, orci augue tempus lacus,
    id venenatis sapien nisl a est. Sed accumsan massa sed libero consectetur
    scelerisque. Class aptent taciti sociosqu ad litora torquent per conubia
    nostra, per inceptos himenaeos. Sed nunc risus, lobortis id egestas nec,
    suscipit id magna. Morbi at iaculis mauris. Proin felis sem, tempus non
    pellentesque congue, vehicula sit amet eros. Maecenas porttitor erat ac
    dolor pharetra iaculis. Cras tincidunt, nulla eget malesuada egestas, sem
    diam consequat quam, sed feugiat nulla orci at mauris. Quisque non arcu
    diam, ac lacinia felis. Nunc iaculis mollis egestas. Etiam imperdiet dolor
    consectetur eros feugiat fringilla sed in lacus. Nunc nec tincidunt dolor.
    Etiam sagittis tortor condimentum nunc fermentum vestibulum. Vivamus
    lobortis, magna sit amet scelerisque lobortis, sem eros molestie leo, eget
    aliquet ligula est in lectus. Duis placerat porta pulvinar. Sed sed
    adipiscing ante. Vestibulum ante ipsum primis in faucibus orci luctus et
    ultrices posuere cubilia Curae; Nam accumsan iaculis augue, sed varius dui
    sagittis id. Etiam sit amet eleifend augue.

    Ut sit amet nibh sit amet justo tempor condimentum. Ut faucibus sagittis
    volutpat. Duis vestibulum feugiat sollicitudin. Aenean cursus luctus urna
    at consectetur. Nullam tincidunt, eros a iaculis sodales, tellus est
    imperdiet arcu, sit amet tincidunt orci felis et tortor. Mauris rutrum
    venenatis nunc ut rutrum. Phasellus nec erat magna, in tincidunt orci. Sed
    sit amet suscipit tellus. Mauris ut nisi turpis. Suspendisse augue turpis,
    condimentum ac bibendum in, vestibulum nec eros. Curabitur dapibus pulvinar
    vehicula. Fusce consequat, erat in malesuada hendrerit, tellus urna
    pharetra lacus, sed euismod nisi urna sed nisi. Etiam fermentum accumsan
    nunc, sed bibendum dui iaculis id. Etiam blandit fermentum ligula nec
    viverra. Vivamus venenatis arcu in nulla euismod euismod. Donec sit amet
    augue nec metus varius fringilla. Vivamus pulvinar elit ac mi rhoncus in
    luctus diam egestas. Curabitur a felis eget arcu pretium tempus eu sed
    mauris. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices
    posuere cubilia Curae;

    Mauris malesuada, nibh ac venenatis hendrerit, ligula dui condimentum
    tellus, sit amet pretium diam tortor vel risus. Suspendisse suscipit
    consequat eros id dignissim. Cras interdum lorem ac massa euismod non porta
    enim pretium. Aliquam ultrices nibh vitae ligula consectetur vel
    sollicitudin lacus volutpat. Phasellus vulputate iaculis sem nec laoreet.
    Nam leo sem, tempor eu condimentum id, imperdiet sed dolor. Donec pharetra
    velit non libero euismod tempor. Vestibulum ante ipsum primis in faucibus
    orci luctus et ultrices posuere cubilia Curae; Sed fermentum, libero a
    posuere posuere, enim elit imperdiet enim, a sollicitudin est felis non
    libero. Sed vel dolor ut arcu dapibus iaculis nec a mauris. Morbi
    ullamcorper ultrices venenatis. Fusce luctus ante sit amet lacus venenatis
    ut rutrum elit lobortis. Nulla fermentum tortor ac sapien fringilla quis
    iaculis quam egestas.

    Aliquam et tortor est, at elementum mauris. Morbi posuere erat nec leo
    vulputate in pellentesque tortor condimentum. Vestibulum at orci augue.
    Aenean pellentesque sapien id felis consequat varius. Suspendisse bibendum
    enim sit amet mi imperdiet vel suscipit nisi tristique. Curabitur velit
    massa, consectetur ac mattis vel, accumsan at nunc. Donec porta, nibh nec
    consequat convallis, urna neque auctor erat, eu convallis lorem leo
    convallis turpis. Morbi non mauris non metus ornare vulputate. Sed aliquet,
    dolor ut egestas fermentum, metus purus mollis elit, nec commodo odio quam
    quis nisl. Aliquam erat volutpat. Suspendisse sed faucibus urna. Integer
    suscipit rutrum condimentum. Praesent dignissim libero eget metus luctus
    consectetur.

    Vestibulum ac erat felis, vitae iaculis erat. Duis interdum lacinia arcu,
    non lacinia urna luctus in. Curabitur feugiat sapien sapien, in vestibulum
    diam. Phasellus lobortis massa ut metus pretium dignissim. Fusce quis sem
    odio. Integer pellentesque sodales augue id tincidunt. Pellentesque
    habitant morbi tristique senectus et netus et malesuada fames ac turpis
    egestas. Vestibulum lorem odio, semper vel scelerisque sit amet, sagittis
    ac libero. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices
    posuere cubilia Curae; Nam egestas ultricies dui at gravida. Duis
    tristique, eros id consectetur pellentesque, nulla arcu ultricies tortor,
    ut pulvinar sapien lacus in elit. Vivamus dolor massa, pulvinar at mollis
    vitae, euismod ut dolor. Vivamus a magna ante. Vestibulum vitae fringilla
    leo. Ut gravida magna in quam fringilla ultricies. Mauris rhoncus enim id
    sem interdum blandit. Pellentesque luctus leo sit amet felis viverra ac
    accumsan purus mollis. Aenean pretium fringilla quam nec laoreet.

    Nulla id mauris mauris. Nam varius bibendum tristique. Integer ante felis,
    volutpat sed dignissim vel, interdum molestie nisi. Etiam mollis accumsan
    elit, ut gravida eros molestie nec. Nullam quis velit ac purus imperdiet
    sodales. Donec semper placerat venenatis. Cras dolor risus, sodales sed
    scelerisque nec, sollicitudin pretium felis. Quisque pretium felis id
    turpis bibendum pulvinar ornare id nibh. Morbi lobortis leo non mi
    porttitor vulputate. Vestibulum nec odio tellus, ut blandit ligula. In
    pellentesque neque sit amet dui pulvinar sed laoreet dui vehicula. In hac
    habitasse platea dictumst. Etiam feugiat dictum blandit. Praesent lacinia
    tincidunt elit, quis consectetur tortor molestie commodo.

    Ut sit amet accumsan lorem. Cras quam nunc, malesuada tempor volutpat
    vitae, aliquam eu diam. Sed sem nibh, bibendum nec sollicitudin at,
    interdum et magna. Cum sociis natoque penatibus et magnis dis parturient
    montes, nascetur ridiculus mus. Aliquam vitae sem non elit pharetra
    vestibulum et condimentum libero. Nam egestas ultricies hendrerit. Nunc nec
    fringilla nulla. Aliquam risus tellus, hendrerit non dapibus a, tincidunt
    vel ante. Vivamus mollis, magna et lacinia tincidunt, dui massa porta odio,
    ac ornare felis massa nec lorem. Mauris sagittis lacus sed metus mollis ac
    egestas lectus porttitor. Lorem ipsum dolor sit amet, consectetur
    adipiscing elit. Cum sociis natoque penatibus et magnis dis parturient
    montes, nascetur ridiculus mus. Integer vitae lacinia libero. Phasellus at
    neque enim, sit amet dictum mi.

    Ut risus nisi, vestibulum vel congue eget, egestas in ipsum. Duis faucibus
    tempus sodales. Duis convallis pellentesque arcu rhoncus congue. Nunc ac
    mauris eu purus vestibulum congue. Praesent convallis semper augue vel
    volutpat. Integer dictum varius placerat. Vestibulum convallis tortor non
    mi lacinia ac aliquet dui ultricies. Donec ultrices purus eros. Maecenas
    venenatis posuere massa, nec consectetur lacus cursus eget. Donec quam
    lacus, tempus id placerat et, posuere sed libero. Proin auctor diam ut arcu
    viverra ut imperdiet tellus dapibus.

    Morbi ac mauris quis tellus porttitor eleifend. Sed et ante magna, ut
    sodales sapien. Vestibulum ante ipsum primis in faucibus orci luctus et
    ultrices posuere cubilia Curae; Integer mattis venenatis mi non
    ullamcorper. Vestibulum magna enim, aliquam non interdum ut, dignissim
    vitae ante. Praesent dignissim, est at pretium posuere, nisl ante varius
    felis, vitae posuere enim nulla et nunc. Morbi sagittis suscipit leo, eu
    accumsan ligula volutpat non. Donec ut tincidunt magna. Integer ac libero
    mi. Sed non eros dolor, in tincidunt enim. Curabitur iaculis erat quis
    felis iaculis ut volutpat augue malesuada. Pellentesque eget arcu ligula,
    ut volutpat purus. Suspendisse dictum lorem quis sapien lacinia pretium.
    Lorem ipsum dolor sit amet, consectetur adipiscing elit.

    Proin sagittis egestas massa et tempor. Mauris et eros ante, id porta sem.
    Duis ac eros vitae ipsum ultrices malesuada eget a risus. Morbi imperdiet,
    est a hendrerit tristique, mi erat molestie lacus, ac tempor risus nulla id
    erat. Pellentesque habitant morbi tristique senectus et netus et malesuada
    fames ac turpis egestas. Etiam congue, lacus quis ultricies consequat, diam
    metus convallis enim, ut volutpat enim urna vitae erat. In quam risus,
    molestie et dapibus id, elementum sit amet ligula. Nam faucibus lacus id
    dolor facilisis viverra. Nullam vehicula massa ac arcu consectetur
    vulputate. Praesent nec augue ac justo dapibus vehicula. Aliquam
    consectetur hendrerit dolor, et mollis nisl auctor ut.

    Ut sagittis risus at felis fringilla ultricies. Vestibulum non urna nibh,
    nec pretium dolor. Nulla imperdiet lobortis eros at pharetra. Vivamus
    cursus pellentesque ornare. Lorem ipsum dolor sit amet, consectetur
    adipiscing elit. Fusce arcu quam, pulvinar at rutrum vitae, ornare vitae
    leo. Maecenas vehicula magna sit amet nulla bibendum condimentum. Curabitur
    ultrices tempor fringilla. Vivamus pretium suscipit molestie. Donec arcu
    diam, ultricies ac pellentesque eu, venenatis et sapien.

    Nam dictum orci augue, vel eleifend leo. Nam at lacus sapien, nec pretium
    eros. In egestas, enim sed sagittis feugiat, purus odio tristique lectus,
    vel condimentum leo turpis ac odio. Nam iaculis mi quis odio posuere et
    venenatis velit ultricies. Nulla facilisi. Proin nec dolor ac quam euismod
    gravida quis et eros. Nam interdum condimentum mattis. Cum sociis natoque
    penatibus et magnis dis parturient montes, nascetur ridiculus mus. Praesent
    a nisi eu massa mollis posuere sed a nunc. Aenean tempus enim a justo
    rhoncus quis ultrices nisl commodo.

    Aenean imperdiet mauris a ipsum venenatis vel scelerisque lorem rutrum.
    Donec ut nunc eros, eget accumsan felis. Nullam ullamcorper porta dictum.
    Donec accumsan cursus vestibulum. Aenean in sapien velit. Vivamus nec massa
    mi. Fusce felis tortor, bibendum non volutpat a, fringilla quis nisi. Duis
    varius bibendum erat, quis fermentum sem accumsan eget. Maecenas massa
    felis, porta sed laoreet eu, luctus eu lectus. Cras id nibh vitae erat
    fringilla rutrum. Maecenas eget consequat est. Vivamus viverra, felis vel
    faucibus rhoncus, quam ipsum elementum libero, quis convallis urna purus ut
    mauris. Nam quis urna vitae enim consequat placerat. Vivamus congue augue
    sit amet lectus luctus tempor. Cras ut justo convallis est egestas
    pellentesque ac nec orci.

    Vivamus rutrum bibendum ante, at cursus erat pulvinar ornare. Proin
    imperdiet scelerisque ante eu vestibulum. Nullam ullamcorper metus nec
    purus auctor lobortis. Proin sed lacus et ipsum tempor tempus. Vivamus odio
    dolor, vulputate vitae semper sit amet, aliquet egestas orci. Nullam non
    quam eu quam sagittis porta. Nunc in velit id erat commodo viverra.
    Praesent nec est augue, nec sagittis erat. Cras sed turpis quis enim tempor
    sagittis. Donec in justo ac nisl porta condimentum id vestibulum nulla. Nam
    elementum ultricies nunc a bibendum.

    Aenean tincidunt nisl non augue pellentesque sit amet convallis neque
    semper. Cras placerat suscipit massa sed volutpat. Integer vulputate
    imperdiet enim, vitae vulputate sapien mattis feugiat. Vivamus pharetra
    facilisis mauris a gravida. Nulla non venenatis est. Duis lobortis
    consectetur sem ac aliquam. In eget sapien odio. Vivamus pulvinar ultricies
    magna, quis laoreet dui porta et. Integer tempus malesuada velit, et
    consequat odio ultrices sed. Aliquam malesuada commodo diam vel posuere.
    Morbi porttitor, elit vitae auctor gravida, lorem massa bibendum arcu, vel
    placerat nulla justo at augue.

    Aliquam libero quam, mattis blandit congue sit amet, fermentum ac augue.
    Aliquam malesuada molestie vulputate. Duis id porta augue. Vestibulum diam
    dolor, ultrices sit amet porttitor id, convallis id lectus. Etiam ac augue
    tincidunt nisi tempor molestie euismod id nisl. Nam et tortor ac arcu
    viverra pulvinar. Fusce pulvinar rhoncus leo, a faucibus enim interdum non.
    Aliquam vulputate mattis consectetur. Pellentesque sit amet quam sem. Cras
    eget arcu eu elit volutpat volutpat. Integer sed varius enim. Integer sit
    amet felis orci, id dignissim sapien. Sed vitae lorem sed libero facilisis
    fringilla. Pellentesque congue tristique purus, eleifend semper risus
    suscipit quis. Phasellus rutrum quam vitae arcu vulputate porta. Sed
    tristique arcu nec mi porttitor lacinia.

    Donec congue feugiat diam quis pretium. Vivamus at luctus nunc. Integer
    vulputate laoreet mauris quis auctor. Nunc at ultrices libero. Maecenas
    porta faucibus purus non vehicula. Sed sit amet metus vitae mi ultrices
    scelerisque nec quis risus. Phasellus pellentesque tincidunt massa id
    ultricies. Aliquam dictum arcu ac dolor interdum rutrum. Nulla facilisi.
    Duis nisi est, tincidunt a sagittis id, sollicitudin at odio. Curabitur sed
    est eu sapien faucibus dignissim in quis tortor.

    Nunc ac elit tortor, non lobortis massa. Proin posuere ante ut metus
    vehicula suscipit. Proin mattis mauris ac lectus consequat rutrum. Nam arcu
    lectus, commodo non pretium a, pharetra semper dolor. Fusce eleifend
    hendrerit adipiscing. Nunc et eleifend erat. Suspendisse tempus nisl ut
    arcu blandit ut adipiscing nisi tristique. Suspendisse molestie facilisis
    risus sed fermentum. Praesent tempor convallis ultricies. Integer et elit
    velit, at consectetur risus.

    Vestibulum mollis adipiscing sodales. Vestibulum ante ipsum primis in
    faucibus orci luctus et ultrices posuere cubilia Curae; Mauris dictum
    molestie porta. Nam convallis nisl quis lacus vulputate in convallis risus
    sagittis. Vivamus accumsan faucibus cursus. Ut ultricies imperdiet ligula
    scelerisque blandit. In ornare egestas purus, at convallis velit egestas
    laoreet. Class aptent taciti sociosqu ad litora torquent per conubia
    nostra, per inceptos himenaeos. Nulla quis imperdiet est. Nunc tempus magna
    quis lacus feugiat et posuere lacus vehicula. Cras lacinia aliquam est at
    vehicula. Aenean congue elit in ante dignissim vitae fermentum lectus
    aliquam. Mauris at odio magna, at interdum dui. Cras fringilla mi velit,
    nec varius neque.

    Fusce et volutpat lacus. Suspendisse id turpis et urna varius convallis in
    eu purus. Nulla facilisi. Etiam mauris nisl, ultrices ac porttitor sit
    amet, facilisis ut neque. Nullam ut velit quis velit tincidunt rhoncus.
    Praesent tristique porttitor euismod. Nulla non felis ante, feugiat commodo
    turpis. In nec venenatis mi. Duis tempus tempor purus, vitae consectetur mi
    ornare eu. Proin sed consequat erat. Quisque nec sem dui. Nam semper,
    ligula facilisis pretium interdum, diam lectus sollicitudin lorem, in
    elementum nisi lorem scelerisque justo. Nullam ac fringilla nunc. Maecenas
    malesuada ligula in massa sollicitudin sit amet auctor ipsum malesuada.
    Vestibulum ut augue in magna lobortis varius eget in ipsum. In hac
    habitasse platea dictumst.

    Cras vel sagittis mi. Aenean urna sapien, ultrices et tristique et, aliquam
    vel libero. Nullam in consequat ante. Suspendisse libero augue, pulvinar a
    dignissim vitae, fringilla malesuada dui. Phasellus augue ante, pulvinar
    eget tincidunt vel, venenatis sed arcu. Pellentesque ac purus orci, vel
    molestie turpis. Nulla consectetur sollicitudin dolor, sed ornare arcu
    accumsan fermentum. Fusce vestibulum nisi at leo interdum eu sollicitudin
    lacus dictum. Fusce malesuada consequat ipsum ut convallis. Maecenas in
    eros sit amet elit consectetur fringilla nec a nibh. Ut et velit vel ligula
    pharetra elementum. Nullam aliquam, tellus vel cursus lacinia, dui libero
    dictum turpis, nec lacinia dolor nunc vel diam. Pellentesque convallis dui
    quis lacus ornare at rutrum lorem pellentesque. Suspendisse potenti. Cum
    sociis natoque penatibus et magnis dis parturient montes, nascetur
    ridiculus mus.

    Nunc ac nibh sed mauris ornare cursus. Praesent enim mauris, tincidunt
    vitae convallis ac, ultricies imperdiet sapien. Duis sodales ligula eget
    lorem suscipit sed consectetur metus pretium. Nam in magna augue, quis
    volutpat mauris. Quisque pretium lobortis orci quis laoreet. Nam ut nisi
    diam. Sed ultrices ultrices dapibus. Integer feugiat mauris id orci
    pulvinar eu tempus nibh viverra. Etiam venenatis bibendum massa a
    consequat. Fusce interdum velit ac mauris rhoncus non cursus neque
    consectetur. Vestibulum dictum eros ac metus fringilla venenatis. Phasellus
    auctor dui non nulla molestie id malesuada mauris euismod. Aenean id tortor
    ac justo eleifend mollis non vel arcu. Duis ac lorem tortor. Donec volutpat
    purus sed nunc luctus interdum hendrerit nulla ullamcorper. Sed consectetur
    interdum aliquet. Proin ullamcorper risus ut ante lacinia sagittis. Nunc
    varius eleifend purus, ac pellentesque urna viverra id. Praesent euismod,
    sapien accumsan gravida dictum, massa massa euismod sapien, ut auctor
    tellus arcu sed diam.

    Vivamus tincidunt dolor non lorem pellentesque at tempus elit adipiscing.
    Vestibulum tempor aliquam consectetur. Mauris nec dictum nisl. Donec
    scelerisque ornare condimentum. Phasellus laoreet justo nec nibh convallis
    convallis. Duis id orci sapien, eget pulvinar justo. Aenean id arcu felis,
    eu iaculis nibh. Aenean eleifend pretium rutrum. Aliquam molestie sem quis
    tellus aliquam eleifend. Mauris et purus orci. Nunc et accumsan tortor.
    Phasellus semper eleifend nisi, a faucibus risus vehicula id. Lorem ipsum
    dolor sit amet, consectetur adipiscing elit. Maecenas in felis et est
    lacinia eleifend vel sed ipsum. Aliquam commodo molestie lorem id
    hendrerit. Nam sed tellus urna, sed dignissim eros.

    """

    return A_LONG_STRING



# mode: run
# tag: condexpr
# ticket: 267

cimport cython

def ident(x): return x

def constants(x):
    """
    >>> constants(4)
    1
    >>> constants(5)
    10
    """
    a = 1 if x < 5 else 10
    return a

def temps(x):
    """
    >>> temps(4)
    1
    >>> temps(5)
    10
    """
    return ident(1) if ident(x) < ident(5) else ident(10)


def nested(x):
    """
    >>> nested(1)
    1
    >>> nested(2)
    2
    >>> nested(3)
    3
    """
    a = 1 if x == 1 else (2 if x == 2 else 3)
    return a


@cython.test_fail_if_path_exists('//CondExprNode')
def const_true(a,b):
    """
    >>> const_true(1,2)
    1
    """
    return a if 1 == 1 else b

@cython.test_fail_if_path_exists('//CondExprNode')
def const_false(a,b):
    """
    >>> const_false(1,2)
    2
    """
    return a if 1 != 1 else b
